@@ -208,6 +208,10 @@ cifUniqueCell(cifNum)
     if (def == (CellDef *)NULL)
 	return;
 
+    /* Cell may have been called but not yet defined---this is okay. */
+    else if ((def->cd_flags & CDAVAILABLE) == 0)
+	return;
+
     testdef = def;
     while (testdef != NULL)
     {
