@@ -51,6 +51,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/comm
 #include "drc/drc.h"
 #include "textio/txcommands.h"
 #include "utils/styles.h"
+#include "graphics/graphics.h"
 #include "extract/extract.h"
 #include "utils/malloc.h"
 #include "select/select.h"
@@ -67,7 +68,53 @@ struct cmdFillArea
     TileType cfa_type;			/* Type of material. */
     struct cmdFillArea *cfa_next;	/* Next in list of areas to fill. */
 };
-
+
+/* The following structure passes arguments needed by the	  */
+/* DBWFeedbackAdd command to the feedPolyFunc() callback routine. */
+
+struct cmdFPArg
+{
+   CellDef *def;
+   int style;
+   char *text;
+};
+
+#define FEEDMAGNIFY 20	/* Allow feedback to be drawn to 1/20 of an 	*/
+			/* internal unit.				*/
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * feedPolyFunc --
+ *
+ *	This procedure generates feedback entries in a polygonal area
+ *	by calling DBWFeedbackArea per tile on simple 1-bit types in
+ *	a plane.  The use of the temporary plane allows us to use the
+ *	same path decomposition routine used for CIF input, polygon
+ *	drawing, and wire segments.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+int
+feedPolyFunc(tile, arg)
+    Tile *tile;
+    struct cmdFPArg *arg;
+{
+    Rect area;
+    TiToRect(tile, &area);
+
+    DBWFeedbackAdd(&area, arg->text, arg->def, FEEDMAGNIFY,
+#ifdef NONMANHATTAN
+        arg->style |
+                (TiGetTypeExact(tile) & (TT_DIAGONAL | TT_DIRECTION | TT_SIDE)));
+        /* (preserve information about the geometry of a diagonal tile) */
+#else
+        arg->style);
+#endif
+    return 0;
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -106,8 +153,8 @@ CmdFeedback(w, cmd)
 {
     static char *cmdFeedbackOptions[] =
     {
-	"add text [style]		create new feedback area over box",
-	"clear				clear all feedback info",
+	"add text [style] [points...]	create new feedback area over box",
+	"clear [substring]		clear all or selected feedback info",
 	"count				count # feedback entries",
 	"find [nth]			put box over next [or nth] entry",
 	"help				print this message",
@@ -128,8 +175,8 @@ CmdFeedback(w, cmd)
     static int nth = 0;			/* Last entry displayed in
 					 * "feedback find".
 					 */
-    int option, i, style;
-    Rect box;
+    int option, i, style, pstart;
+    Rect box, r;
     char *text, **msg;
     CellDef *rootDef;
     HashTable table;
@@ -154,34 +201,173 @@ CmdFeedback(w, cmd)
 	TxError("    save\n");
 	return;
     }
+    pstart = 4;		/* argument # where point list starts, if any */
     switch (option)
     {
 	case ADD:
-	    if (cmd->tx_argc == 3) style = STYLE_PALEHIGHLIGHTS;
-	    else
+	    style = STYLE_PALEHIGHLIGHTS;
+	    if (cmd->tx_argc > 3)
 	    {
-		if (cmd->tx_argc != 4) goto badusage;
 		i = Lookup(cmd->tx_argv[3], cmdFeedbackStyleNames);
 		if (i < 0)
 		{
-		    TxError("%s isn't a valid display style.  Try one of:\n",
-			cmd->tx_argv[3]);
-		    TxError("    dotted        pale\n");
-		    TxError("    medium        solid\n");
-		    TxError("    outline\n");
-		    break;
+		    if (StrIsNumeric(cmd->tx_argv[3]))
+			pstart = 3;
+		    else
+		    {
+		        style = GrGetStyleFromName(cmd->tx_argv[3]);
+			if (style < 0)
+			{
+			    TxError("%s isn't a valid display style.  Try one of:\n",
+					cmd->tx_argv[3]);
+			    TxError("    dotted, pale, mediaum, solid, outline,\n");
+			    TxError("    or a long name from the .dstyle file\n");
+			    break;
+			}
+			if (style < 1 || style >= TECHBEGINSTYLES)
+	 		{
+			    TxError("Numbered styles must be between 1 and %d\n",
+					TECHBEGINSTYLES - 1);
+			    break;
+			}
+		    }
 		}
-		style = cmdFeedbackStyles[i];
+		else style = cmdFeedbackStyles[i];
+	    }
+	    if (cmd->tx_argc - pstart > 0)
+	    {
+		/* points must be in X Y pairs */
+		if ((cmd->tx_argc - pstart) & 1) goto badusage;
+
+	        if (w == NULL) return;
+		rootDef = ((CellUse *) w->w_surfaceID)->cu_def;
+
+		/* Read coordinates in FEEDMAGNIFY x internal units,	*/
+		/* then scale the highlight accordingly.		*/
+
+		if ((cmd->tx_argc - pstart) == 2)
+		{
+		    /* Single point highlight.  Style MUST be outlined	*/
+		    /* or else the point won't be visible.		*/
+
+		    if (GrStyleTable[style].outline == 0)
+			style = STYLE_OUTLINEHIGHLIGHTS;
+
+		    box.r_xbot = box.r_xtop = cmdScaleCoord(w, cmd->tx_argv[pstart++],
+				FALSE, TRUE, FEEDMAGNIFY);
+		    box.r_ybot = box.r_ytop = cmdScaleCoord(w, cmd->tx_argv[pstart++],
+				FALSE, FALSE, FEEDMAGNIFY);
+
+		    DBWFeedbackAdd(&box, cmd->tx_argv[2], rootDef, FEEDMAGNIFY, style);
+		}
+		else if ((cmd->tx_argc - pstart) == 4)
+		{
+		    /* Single line highlight.  Style MUST be outlined,	*/
+		    /* or else the line won't be visible.		*/
+
+		    if (GrStyleTable[style].outline == 0)
+			style = STYLE_OUTLINEHIGHLIGHTS;
+		    r.r_xbot = cmdScaleCoord(w, cmd->tx_argv[pstart++],
+				FALSE, TRUE, FEEDMAGNIFY);
+		    r.r_ybot = cmdScaleCoord(w, cmd->tx_argv[pstart++],
+				FALSE, FALSE, FEEDMAGNIFY);
+		    r.r_xtop = cmdScaleCoord(w, cmd->tx_argv[pstart++],
+				FALSE, TRUE, FEEDMAGNIFY);
+		    r.r_ytop = cmdScaleCoord(w, cmd->tx_argv[pstart++],
+				FALSE, FALSE, FEEDMAGNIFY);
+		    if (r.r_xbot != r.r_xtop && r.r_ybot != r.r_ytop)
+		    {
+			/* Line at an angle.  The hack of setting TT_SIDE */
+			/* without setting TT_DIAGONAL allows the drawing */
+			/* routine to treat this case as a line, not a	  */
+			/* triangle.					  */
+
+			style |= TT_SIDE;
+			if ((r.r_xbot > r.r_xtop && r.r_ybot < r.r_ytop) ||
+				(r.r_xbot < r.r_xtop && r.r_ybot > r.r_ytop))
+			    style |= TT_DIRECTION;
+		    }
+		    GeoCanonicalRect(&r, &box);
+		    DBWFeedbackAdd(&box, cmd->tx_argv[2], rootDef, FEEDMAGNIFY, style);
+		}
+		else
+		{
+		    Plane *plane;
+		    PaintResultType ptable[2] = {1, 1}; /* simple 1 bit table */
+		    TileTypeBitMask feedSimpleMask;
+		    Point *plist;
+		    int points, j;
+		    struct cmdFPArg fpargs;
+
+		    points = (cmd->tx_argc - pstart) >> 1;
+		    plist = (Point *)mallocMagic(points * sizeof(Point));
+		    fpargs.def = rootDef;
+		    fpargs.style = style;
+		    fpargs.text = cmd->tx_argv[2];
+
+		    for (i = 0, j = pstart; i < points; i++) 
+		    {
+			plist[i].p_x = cmdScaleCoord(w, cmd->tx_argv[j++],
+				FALSE, TRUE, FEEDMAGNIFY);
+			plist[i].p_y = cmdScaleCoord(w, cmd->tx_argv[j++],
+				FALSE, FALSE, FEEDMAGNIFY);
+		    }
+		    plane = DBNewPlane((ClientData)0);
+		    TTMaskZero(&feedSimpleMask);
+		    TTMaskSetType(&feedSimpleMask, 1);
+		    PaintPolygon(plist, points, plane, ptable, (PaintUndoInfo *)NULL);
+		    i = DBWFeedbackCount;
+		    DBSrPaintArea((Tile *)NULL, plane, &TiPlaneRect, &feedSimpleMask,
+			feedPolyFunc, (ClientData)&fpargs);
+		    TiFreePlane(plane);
+
+		    if (i == DBWFeedbackCount)
+		    {
+			/* Pathological condition---feedback area is so thin	*/
+			/* that the decomposition to rectangles and triangles	*/
+			/* was degenerate.  If so, then we can just treat the	*/
+			/* plist as several lines and/or points.		*/
+
+			if (GrStyleTable[style].outline == 0)
+			    style = STYLE_OUTLINEHIGHLIGHTS;
+
+			for (i = 0; i < points - 1; i++)
+			{
+			    r.r_xbot = plist[i].p_x;
+			    r.r_ybot = plist[i].p_y;
+			    r.r_xtop = plist[i + 1].p_x;
+			    r.r_ytop = plist[i + 1].p_y;
+			    if (r.r_xbot != r.r_xtop && r.r_ybot != r.r_ytop)
+		    	    {
+				style |= TT_SIDE;
+				if ((r.r_xbot > r.r_xtop && r.r_ybot < r.r_ytop) ||
+					(r.r_xbot < r.r_xtop && r.r_ybot > r.r_ytop))
+			    	style |= TT_DIRECTION;
+			    }
+			    GeoCanonicalRect(&r, &box);
+			    DBWFeedbackAdd(&box, cmd->tx_argv[2], rootDef,
+						FEEDMAGNIFY, style);
+			}
+		    }
+		    freeMagic(plist);
+		}	
+	    }
+	    else
+	    {
+		w = ToolGetBoxWindow(&box, (int *) NULL);
+	        if (w == NULL) return;
+		rootDef = ((CellUse *) w->w_surfaceID)->cu_def;
+		DBWFeedbackAdd(&box, cmd->tx_argv[2], rootDef, 1, style);
 	    }
-	    w = ToolGetBoxWindow(&box, (int *) NULL);
-	    if (w == NULL) return;
-	    rootDef = ((CellUse *) w->w_surfaceID)->cu_def;
-	    DBWFeedbackAdd(&box, cmd->tx_argv[2], rootDef, 1, style);
 	    break;
 	
 	case CLEAR:
-	    if (cmd->tx_argc != 2) goto badusage;
-	    DBWFeedbackClear();
+	    if (cmd->tx_argc == 3)
+	        DBWFeedbackClear(cmd->tx_argv[2]);
+	    else if (cmd->tx_argc == 2)
+	        DBWFeedbackClear(NULL);
+	    else
+		goto badusage;
 	    nth = 0;
 	    break;
 	
@@ -270,7 +456,7 @@ CmdFeedback(w, cmd)
 	    if (w == NULL) return;
 	    rootDef = ((CellUse *) w->w_surfaceID)->cu_def;
 	    HashInit(&table, 16, 0);
-	    for (i=0; i<DBWFeedbackCount; i++)
+	    for (i = 0; i < DBWFeedbackCount; i++)
 	    {
 		Rect area;
 		CellDef *fbRootDef;
