@@ -247,7 +247,7 @@ showTech(outf, verbose)
     fprintf(outf, "\n\014Component Layers:\n");
     for (i = 0; i < DBNumUserLayers; i++)
 	for (j = 0; j < DBNumUserLayers; j++)
-	    if ((j != i) && TTMaskHasType(&DBComponentTbl[j], i))
+	    if ((j != i) && TTMaskHasType(DBResidueMask(j), i))
 		fprintf(outf, "%s is a component of %s\n",
 		    DBTypeLongName(i), DBTypeLongName(j));
     fprintf(outf, "\n");
