@@ -2285,6 +2285,15 @@ DBCellWrite(cellDef, fileName)
      */
     if (tmpf = fopen(tmpname, "w"))
     {
+	/* mkstemp() generates a file with permissions 0600 */
+	/* We want instead to respect the user's umask	    */
+	/* value so the .mag file gets the write	    */
+	/* permissions when doing rename().		    */
+
+	mode_t userumask = umask((mode_t)0);
+	umask(userumask);
+	chmod(tmpname, (mode_t)0666 & ~userumask);
+
 	result = DBCellWriteFile(cellDef, tmpf);
 	(void) fclose(tmpf);
 	tmpf = NULL;
@@ -2314,16 +2323,6 @@ DBCellWrite(cellDef, fileName)
 		    tmpname, expandname, expandname, cellDef->cd_name, tmpname);
 	    goto cleanup;
 	}
-	else
-	{
-	    /* mkstemp() generates a file with permissions 0600 */
-	    /* This is okay for the temporary file, but we want	*/
-	    /* to respect the user's umask value when renaming	*/
-	    /* the file to ".mag".				*/
-	    mode_t userumask = umask((mode_t)0);
-	    umask(userumask);
-	    chmod(expandname, (mode_t)0666 & ~userumask);
-	}
     }
     else
     {
