@@ -347,8 +347,10 @@ dbTechAddOneStackedContact(type1, type2)
     /* Both types must be contacts */
     if (!lim->l_isContact || !lin->l_isContact) return -1;
 
-    /* Contacts do not stack if they share all the same planes */
-    if (lim->l_pmask == lin->l_pmask) return -1;
+    /* Contacts do not stack if they share more than one plane */
+    /* if (lim->l_pmask == lin->l_pmask) return -1; */
+    if (((lim->l_pmask & lin->l_pmask) & ((lim->l_pmask & lin->l_pmask) - 1)) != 0)
+	return -1;
 
     TTMaskAndMask3(&ttshared, &lim->l_residues, &lin->l_residues);
 
