@@ -664,7 +664,8 @@ DBTechNoisyNameMask(layers, mask)
 		    }
 
 		    t = DBTechNoisyNameType(p);
-		    if (t >= 0) m2 = DBLayerTypeMaskTbl[t];
+		    if (t >= 0)
+			m2 = DBLayerTypeMaskTbl[t];
 
 		    /* Include all types which have t as a residue */
 		    if (allResidues)
