@@ -357,7 +357,8 @@ DBTechAddType(sectionName, argc, argv)
     if (!strcmp(argv[0], "alias"))
     {
 	HashEntry *he;
-	TileTypeBitMask *amask;
+	TileType atype;
+	TileTypeBitMask *amask, tmask;
 
 	/* First check that the alias name does not shadow an existing type */
 	if (DBTechNameType(argv[1]) >= 0)
@@ -366,12 +367,25 @@ DBTechAddType(sectionName, argc, argv)
 	    return TRUE;
 	}
 
+	/* Next, check the type list.  If there is only one type, then	*/  
+	/* add the name to the type's names as usual, instead of adding	*/  
+	/* it to the alias hash table, which is meant for names that	*/  
+	/* map to multiple types.					*/
+
+	DBTechNoisyNameMask(argv[2], &tmask);
+	if ((atype = DBTechNameType(argv[2])) >= 0)
+	    if (TTMaskEqual(&DBLayerTypeMaskTbl[atype], &tmask))
+	    {
+		DBTechAddNameToType(argv[1], atype);
+		return TRUE;
+	    }
+
 	he = HashFind(&DBTypeAliasTable, argv[1]);
 	amask = (TileTypeBitMask *)HashGetValue(he);
 	if (amask == NULL)
 	{
 	    amask = (TileTypeBitMask *)mallocMagic(sizeof(TileTypeBitMask));
-	    DBTechNoisyNameMask(argv[2], amask);
+	    TTMaskSetMask(amask, &tmask);
 	    HashSetValue(he, amask);
 	}
 	else
@@ -392,6 +406,7 @@ DBTechAddType(sectionName, argc, argv)
 
 	DBTypeLongNameTbl[DBNumTypes] = cp;
 	DBPlane(DBNumTypes) = pNum;
+	TTMaskSetOnlyType(&DBLayerTypeMaskTbl[DBNumTypes], DBNumTypes);
 	DBNumTypes++;
     }
 
