@@ -39,8 +39,9 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/dbwi
  */
 
 extern void CmdAddPath(), CmdArray();
-extern void CmdBox(), CmdCellname();
-extern void CmdClockwise(), CmdCopy(), CmdCorner(), CmdCrosshair();
+extern void CmdBox(), CmdCellname(), CmdClockwise();
+extern void CmdContact(), CmdCopy(), CmdCorner();
+extern void CmdCrash(), CmdCrosshair();
 extern void CmdDelete(), CmdDown(), CmdDrc(), CmdDump();
 extern void CmdEdit(), CmdElement(), CmdErase(), CmdExpand(), CmdExtract();
 extern void CmdFeedback(), CmdFill(), CmdFindBox(), CmdFindLabel(), CmdFlush();
@@ -56,15 +57,6 @@ extern void CmdTech(), CmdTool(), CmdUnexpand();
 extern void CmdUpsidedown(), CmdWhat(), CmdWire(), CmdWriteall();
 extern void CmdGoto(), CmdFlatten(), CmdXload();
 
-/*
- * TCL-only extensions
- */
-
-#ifdef MAGIC_WRAPPER
-extern void CmdSearch();
-extern void CmdCellsearch();
-#endif
-
 /*
  * Nonmanhattan geometry extensions
  */
@@ -244,6 +236,10 @@ DBWInitCommands()
     WindAddCommand(DBWclientID,
 	"clockwise [deg]		rotate selection and box clockwise",
 	CmdClockwise, FALSE);
+    WindAddCommand(DBWclientID,
+	"contact type		paint contact type on the intersection of its\n"
+	"			residues",
+	CmdContact, FALSE);
     WindAddCommand(DBWclientID,
 	"copy [dir [amount]]	OR\n"
 	"copy to x y		copy selection:  what used to be at box\n"
@@ -255,6 +251,11 @@ DBWInitCommands()
 	"corner d1 d2 [layers]	make L-shaped wires inside box, filling\n"
 	"			first in direction d1, then in d2",
 	CmdCorner, FALSE);
+    WindAddCommand(DBWclientID,
+	"crash save|recover [file]\n"
+	"			recover the crash file \"file\", or the first\n"
+	"			crash file discovered.",
+	CmdCrash, FALSE);		
     WindAddCommand(DBWclientID,
 	"crosshair x y | off	enable and move or disable the screen crosshair",
 	CmdCrosshair, FALSE);		
@@ -507,14 +508,6 @@ DBWInitCommands()
 	"ext2spice [args]	convert extracted file(s) to a SPICE format file;"
 	" type\n\t\t\t\"ext2spice help\" for information on options",
 	CmdAutoExtToSpice, FALSE);
-
-    WindAddCommand(DBWclientID,
-	"search [layers] proc	execute a TCL procedure on each tile in the box area.",
-	CmdSearch, FALSE);
-    WindAddCommand(DBWclientID,
-	"cellsearch [instance] proc\n\
-			execute a TCL procedure on each tile in the box area.",
-	CmdCellsearch, FALSE);
 #endif
 
 
