@@ -260,12 +260,11 @@ drcTile (tile, arg)
     struct drcClientData *arg;
 {
     DRCCookie *cptr;	/* Current design rule on list */
-    Tile *tp;		/* Used for corner checks */
     Rect *rect = arg->dCD_rect;	/* Area being checked */
     Rect errRect;		/* Area checked for an individual rule */
     TileTypeBitMask tmpMask, *rMask;
     unsigned char stackpending = (char)0;
-    bool triggered;		/* Hack for widespacing rule */
+    bool triggered, trigpending;	/* Hack for widespacing rule */
     int cdist, ccdist, result;
 
     arg->dCD_constraint = &errRect;
@@ -334,6 +333,7 @@ drcTile (tile, arg)
     if (LEFT(tile) >= rect->r_xbot)		/* check tile against rect */
     {
 	Tile *tpleft;
+	Tile *tpl, *tpr;
 	TileType tt, to;
 	int edgeTop, edgeBot;
         int top = MIN(TOP(tile), rect->r_ytop);
@@ -409,13 +409,8 @@ drcTile (tile, arg)
 		for (cptr = DRCRulesTbl[to][tt]; cptr != (DRCCookie *) NULL;
 			cptr = cptr->drcc_next)
 		{
-		    if (cptr->drcc_flags & DRC_CATECORNER)
-		    {
-			ccdist = cptr->drcc_cdist;
-			cdist = cptr->drcc_dist;
-		    }
-		    else
-			cdist = cptr->drcc_cdist;
+		    cdist = cptr->drcc_cdist;
+		    trigpending = (cptr->drcc_flags & DRC_TRIGGER) ? TRUE : FALSE;
 
 		    /* Contact images exist in multiple planes; only check	*/
 		    /* rules that are for the plane being checked.		*/
@@ -427,7 +422,7 @@ drcTile (tile, arg)
 		    if ((!(cptr->drcc_flags & DRC_XPLANE)) &&
 				(arg->dCD_plane != cptr->drcc_plane))
 		    {
-			if (cptr->drcc_flags & DRC_TRIGGER) cptr = cptr->drcc_next;
+			if (trigpending) cptr = cptr->drcc_next;
 			continue;
 		    }
 
@@ -458,16 +453,34 @@ drcTile (tile, arg)
 			drcCheckArea(tile,arg,cptr);
 			continue;
 		    }
-		    if (cptr->drcc_flags & (DRC_MAXWIDTH | DRC_BENDS))
+		    if ((cptr->drcc_flags & (DRC_MAXWIDTH | DRC_BENDS)) ==
+				(DRC_MAXWIDTH | DRC_BENDS))
 		    {
 			/* New algorithm --- Tim 3/6/05 */
 			Rect *lr;
 
+			/* Fix (3/13/06):  "maxwidth" rule requires searching	*/
+			/* for areas > than the given maximum, not >=.  To	*/
+			/* find areas of width strictly greater than the	*/
+			/* maximum, we need to add 1 to the rule's distance.	*/
+			/* But this has to be 1 internal unit.  If we add 1	*/
+			/* when we parse the techfile, we will hard-code the	*/
+			/* meaning of 1 internal unit, and we will get an	*/
+			/* incorrect distance if we change the grid scale.  So	*/
+			/* we add 1 (true) internal unit here.  Note that this	*/
+			/* correction is valid ONLY for the new algorithm, and	*/
+			/* only for the "maxwidth" rule itself, not for the	*/
+			/* "widespacing" rule when "maxwidth" is used as a	*/
+			/* trigger rule.					*/
+
+		        if (!trigpending) cptr->drcc_dist++;
+
 			if (cptr->drcc_flags & DRC_REVERSE)
 			    lr = drcCanonicalMaxwidth(tpleft, GEO_WEST, arg, cptr);
 			else
 			    lr = drcCanonicalMaxwidth(tile, GEO_EAST, arg, cptr);
-		        if (cptr->drcc_flags & DRC_TRIGGER)
+		        if (!trigpending) cptr->drcc_dist--;
+		        if (trigpending)
 			{
 			    if (lr)
 			    {
@@ -511,31 +524,54 @@ drcTile (tile, arg)
 		    {
 			/*
 			 * Determine corner extensions.
-			 * Find the point (3) to the bottom right of pointB
 			 */
-			for (tp = tile; BOTTOM(tp) >= errRect.r_ybot; tp = LB(tp))
-			    /* Nothing */;
-			if (TTMaskHasType(&cptr->drcc_corner, TiGetTopType(tp)))
-		 	{
-			    errRect.r_ybot -= cdist;
-			    if (DRCEuclidean)
-				arg->dCD_radial |= 0x1000;
+
+			/* Find the point (3) to the bottom right of pointB */
+			if (BOTTOM(tile) >= edgeBot) tpr = LB(tile);
+			else tpr = tile;
+
+			/* Also find point (2) to check for edge continuation */
+			if (BOTTOM(tpleft) >= edgeBot)
+			    for (tpl = LB(tpleft); RIGHT(tpl) < edgeX; tpl = TR(tpl));
+			else tpl = tpleft;
+
+			/* Make sure the edge actually stops at edgeBot */
+			if ( (TiGetTopType(tpl) != TiGetBottomType(tpleft)) ||
+			     (TiGetTopType(tpr) != TiGetBottomType(tile)) )
+			{
+			    if (TTMaskHasType(&cptr->drcc_corner, TiGetTopType(tpr)))
+		 	    {
+				errRect.r_ybot = edgeBot - cdist;
+				if (DRCEuclidean)
+				    arg->dCD_radial |= 0x1000;
+			    }
 			}
 
 			if (cptr->drcc_flags & DRC_BOTHCORNERS)
 			{
 			    /*
-			     * Check the other corner by finding the
-			     * point (4) to the top right of pointT.
+			     * Check the other corner.
 			     */
-			    if (TOP(tp = tile) <= errRect.r_ytop)
-				for (tp = RT(tp); LEFT(tp) > edgeX; tp = BL(tp))
-				    /* Nothing */;
-			    if (TTMaskHasType(&cptr->drcc_corner, TiGetBottomType(tp)))
+
+			    /* Find point (4) to the top right of pointT */
+			    if (TOP(tile) <= edgeTop)
+				for (tpr = RT(tile); LEFT(tpr) > edgeX; tpr = BL(tpr));
+			    else tpr = tile;
+
+			    /* Also find point (1) to check for edge continuation */
+			    if (TOP(tpleft) <= edgeTop) tpl = RT(tpleft);
+			    else tpl = tpleft;
+
+			    /* Make sure the edge actually stops at edgeBot */
+			    if ( (TiGetBottomType(tpl) != TiGetTopType(tpleft)) ||
+				 (TiGetBottomType(tpr) != TiGetTopType(tile)) )
 			    {
-				errRect.r_ytop += cdist;
-				if (DRCEuclidean)
-				    arg->dCD_radial |= 0x2000;
+				if (TTMaskHasType(&cptr->drcc_corner, TiGetBottomType(tpr)))
+				{
+				    errRect.r_ytop = edgeTop + cdist;
+				    if (DRCEuclidean)
+					arg->dCD_radial |= 0x2000;
+				}
 			    }
 			}
 
@@ -551,7 +587,7 @@ drcTile (tile, arg)
 				&& TTMaskHasType(&cptr->drcc_mask,
 				TiGetRightType(tpleft)))
 			{
-			    if (cptr->drcc_flags & DRC_TRIGGER)
+			    if (trigpending)
 				cptr = cptr->drcc_next;
 			    continue;
 			}
@@ -565,31 +601,54 @@ drcTile (tile, arg)
 		    {
 			/*
 			 * Determine corner extensions.
-			 * Find the point (1) to the top left of pointT
 			 */
-			for (tp = tpleft; TOP(tp) <= errRect.r_ytop; tp = RT(tp))
-			    /* Nothing */;
-			if (TTMaskHasType(&cptr->drcc_corner, TiGetBottomType(tp)))
+
+			/* Find the point (1) to the top left of pointT */
+			if (TOP(tpleft) <= edgeTop) tpl = RT(tpleft);
+			else tpl = tpleft;
+
+			/* Also find point (4) to check for edge continuation */
+			if (TOP(tile) <= edgeTop)
+			    for (tpr = RT(tile); LEFT(tpr) > edgeX; tpr = BL(tpr));
+			else tpr = tile;
+
+			/* Make sure the edge actually stops at edgeBot */
+			if ( (TiGetBottomType(tpl) != TiGetTopType(tpleft)) ||
+			     (TiGetBottomType(tpr) != TiGetTopType(tile)) )
 			{
-			    errRect.r_ytop += cdist;
-			    if (DRCEuclidean)
-				arg->dCD_radial |= 0x8000;
+			    if (TTMaskHasType(&cptr->drcc_corner, TiGetBottomType(tpl)))
+			    {
+				errRect.r_ytop = edgeTop + cdist;
+				if (DRCEuclidean)
+				    arg->dCD_radial |= 0x8000;
+			    }
 			}
 
 			if (cptr->drcc_flags & DRC_BOTHCORNERS)
 			{
 			    /*
-			     * Check the other corner by finding the
-			     * point (2) to the bottom left of pointB.
+			     * Check the other corner.
 			     */
-			    if (BOTTOM(tp = tpleft) >= errRect.r_ybot)
-				for (tp = LB(tp); RIGHT(tp) < edgeX; tp = TR(tp))
-				    /* Nothing */;
-			    if (TTMaskHasType(&cptr->drcc_corner, TiGetTopType(tp)))
+
+			    /* Find point (2) to the bottom left of pointB */
+			    if (BOTTOM(tpleft) >= edgeBot)
+				for (tpl = LB(tpleft); RIGHT(tpl) < edgeX; tpl = TR(tpl));
+			    else tpl = tpleft;
+
+			    /* Also find point (3) to check for edge continuation */
+			    if (BOTTOM(tile) >= edgeBot) tpr = LB(tile);
+			    else tpr = tile;
+
+			    /* Make sure the edge actually stops at edgeBot */
+			    if ( (TiGetTopType(tpl) != TiGetBottomType(tpleft)) ||
+				 (TiGetTopType(tpr) != TiGetBottomType(tile)) )
 			    {
-				errRect.r_ybot -= cdist;
-				if (DRCEuclidean)
-				    arg->dCD_radial |= 0x4000;
+				if (TTMaskHasType(&cptr->drcc_corner, TiGetTopType(tpl)))
+				{
+				    errRect.r_ybot = edgeBot - cdist;
+				    if (DRCEuclidean)
+					arg->dCD_radial |= 0x4000;
+				}
 			    }
 			}
 
@@ -605,7 +664,7 @@ drcTile (tile, arg)
 				&& TTMaskHasType(&cptr->drcc_mask,
 				TiGetLeftType(tile)))
 			{
-			    if (cptr->drcc_flags & DRC_TRIGGER)
+			    if (trigpending)
 				cptr = cptr->drcc_next;
 			    continue;
 			}
@@ -625,26 +684,7 @@ drcTile (tile, arg)
 		    arg->dCD_cptr = cptr;
 		    TTMaskCom2(&tmpMask, &cptr->drcc_mask);
 
-		    if (cptr->drcc_flags & DRC_CATECORNER)
-		    {
-			int tmpy = errRect.r_ybot;
-			errRect.r_ybot = edgeTop + ccdist;
-			if (errRect.r_ybot < errRect.r_ytop)
-			{
-			    result = 0; /* to be finished */
-			}
-			errRect.r_ybot = tmpy;
-			tmpy = errRect.r_ytop;
-			errRect.r_ytop = edgeBot - ccdist;
-			if (errRect.r_ytop > errRect.r_ybot)
-			{
-			    result = 0; /* to be finished */
-			}
-
-			/* (to be done) */
-		    }
-		    else 
-			result = DBSrPaintArea((Tile *) NULL,
+		    result = DBSrPaintArea((Tile *) NULL,
 				arg->dCD_celldef->cd_planes[cptr->drcc_plane],
 				&errRect, &tmpMask, areaCheck, (ClientData) arg);
 
@@ -653,7 +693,7 @@ drcTile (tile, arg)
 		        /* Trigger rule:  If rule check found errors,	*/
 		        /* do the next rule.  Otherwise, skip it.	*/
 
-			if (cptr->drcc_flags & DRC_TRIGGER)
+			if (trigpending)
 			    cptr = cptr->drcc_next;
 		    }
 		}
@@ -743,6 +783,7 @@ checkbottom:
     if (BOTTOM(tile) >= rect->r_ybot)
     {
 	Tile *tpbot;
+	Tile *tpx;
 	TileType tt, to;
 	int edgeLeft, edgeRight;
         int left = MAX(LEFT(tile), rect->r_xbot);
@@ -819,20 +860,15 @@ checkbottom:
 		for (cptr = DRCRulesTbl[to][tt]; cptr != (DRCCookie *) NULL;
 				cptr = cptr->drcc_next)
 		{
-		    if (cptr->drcc_flags & DRC_CATECORNER)
-		    {
-			ccdist = cptr->drcc_cdist;
-			cdist = cptr->drcc_dist;
-		    }
-		    else
-			cdist = cptr->drcc_cdist;
+		    cdist = cptr->drcc_cdist;
+		    trigpending = (cptr->drcc_flags & DRC_TRIGGER) ? TRUE : FALSE;
 
 		    /* Contact images exist in multple planes; only check	*/
 		    /* rules that are for the plane being checked.		*/
 		    if ((!(cptr->drcc_flags & DRC_XPLANE)) &&
 				(arg->dCD_plane != cptr->drcc_plane))
 		    {
-			if (cptr->drcc_flags & DRC_TRIGGER) cptr = cptr->drcc_next;
+			if (trigpending) cptr = cptr->drcc_next;
 			continue;
 		    }
 
@@ -854,16 +890,20 @@ checkbottom:
 		    /* top to bottom */
 
 #ifdef DRC_EXTENSIONS
-		    if (cptr->drcc_flags & (DRC_MAXWIDTH | DRC_BENDS))
+		    if ((cptr->drcc_flags & (DRC_MAXWIDTH | DRC_BENDS)) ==
+				(DRC_MAXWIDTH | DRC_BENDS))
 		    {
 			/* New algorithm --- Tim 3/6/05 */
 			Rect *lr;
 
+		        if (!trigpending) cptr->drcc_dist++;
+
 			if (cptr->drcc_flags & DRC_REVERSE)
 			    lr = drcCanonicalMaxwidth(tpbot, GEO_SOUTH, arg, cptr);
 			else
 			    lr = drcCanonicalMaxwidth(tile, GEO_NORTH, arg, cptr);
-		        if (cptr->drcc_flags & DRC_TRIGGER)
+		        if (!trigpending) cptr->drcc_dist--;
+		        if (trigpending)
 			{
 			    if (lr)
 			    {
@@ -888,7 +928,7 @@ checkbottom:
 		    else if (cptr->drcc_flags & (DRC_AREA|DRC_RECTSIZE|DRC_MAXWIDTH))
 		    {
 			/* only have to do these checks in one direction */
-			if (cptr->drcc_flags & DRC_TRIGGER) cptr = cptr->drcc_next;
+			if (trigpending) cptr = cptr->drcc_next;
 			continue;
 		    }
 #endif
@@ -899,12 +939,14 @@ checkbottom:
 			 * Determine corner extensions.
 			 * Find the point (3) to the top right of pointR
 			 */
-			if (RIGHT(tp = tile) <= errRect.r_xtop)
-			    for (tp = TR(tp); BOTTOM(tp) > edgeY; tp = LB(tp))
-				/* Nothing */;
-		 	if (TTMaskHasType(&cptr->drcc_corner, TiGetLeftType(tp)))
+
+			if (RIGHT(tile) <= edgeRight)
+			    for (tpx = TR(tile); BOTTOM(tpx) > edgeY; tpx = LB(tpx));
+			else tpx = tile;
+
+		 	if (TTMaskHasType(&cptr->drcc_corner, TiGetLeftType(tpx)))
 			{
-			    errRect.r_xtop += cdist;
+			    errRect.r_xtop = edgeRight + cdist;
 			    if (DRCEuclidean)
 				arg->dCD_radial |= 0x4000;
 			}
@@ -915,11 +957,13 @@ checkbottom:
 			     * Check the other corner by finding the
 			     * point (4) to the top left of pointL.
 			     */
-			    for (tp = tile; LEFT(tp) >= errRect.r_xbot; tp = BL(tp))
-				/* Nothing */;
-			    if (TTMaskHasType(&cptr->drcc_corner, TiGetRightType(tp)))
+
+			    if (LEFT(tile) >= edgeLeft) tpx = BL(tile);
+			    else tpx = tile;
+
+			    if (TTMaskHasType(&cptr->drcc_corner, TiGetRightType(tpx)))
 			    {
-				errRect.r_xbot -= cdist;
+				errRect.r_xbot = edgeLeft - cdist;
 				if (DRCEuclidean)
 				    arg->dCD_radial |= 0x1000;
 			    }
@@ -937,7 +981,7 @@ checkbottom:
 				&& TTMaskHasType(&cptr->drcc_mask,
 				TiGetTopType(tpbot)))
 			{
-			    if (cptr->drcc_flags & DRC_TRIGGER)
+			    if (trigpending)
 				cptr = cptr->drcc_next;
 			    continue;
 			}
@@ -953,13 +997,14 @@ checkbottom:
 			 * Determine corner extensions.
 			 * Find the point (1) to the bottom left of pointL
 			 */
-			if (LEFT(tp = tpbot) >= errRect.r_xbot)
-			    for (tp = BL(tp); TOP(tp) < edgeY; tp = RT(tp))
-				/* Nothing */;
 
-			if (TTMaskHasType(&cptr->drcc_corner, TiGetRightType(tp)))
+			if (LEFT(tpbot) >= edgeLeft)
+			    for (tpx = BL(tpbot); TOP(tpx) < edgeY; tpx = RT(tpx));
+			else tpx = tpbot;
+
+			if (TTMaskHasType(&cptr->drcc_corner, TiGetRightType(tpx)))
 			{
-			    errRect.r_xbot -= cdist;
+			    errRect.r_xbot = edgeLeft - cdist;
 			    if (DRCEuclidean)
 				arg->dCD_radial |= 0x2000;
 			}
@@ -970,11 +1015,13 @@ checkbottom:
 			     * Check the other corner by finding the
 			     * point (2) to the bottom right of pointR.
 			     */
-			    for (tp=tpbot; RIGHT(tp) <= errRect.r_xtop; tp=TR(tp))
-				/* Nothing */;
-			    if (TTMaskHasType(&cptr->drcc_corner, TiGetLeftType(tp)))
+
+			    if (RIGHT(tpbot) <= edgeRight) tpx = TR(tpbot);
+			    else tpx = tpbot;
+
+			    if (TTMaskHasType(&cptr->drcc_corner, TiGetLeftType(tpx)))
 			    {
-				errRect.r_xtop += cdist;
+				errRect.r_xtop = edgeRight + cdist;
 				if (DRCEuclidean)
 				    arg->dCD_radial |= 0x8000;
 			    }
@@ -992,7 +1039,7 @@ checkbottom:
 				&& TTMaskHasType(&cptr->drcc_mask,
 				TiGetBottomType(tile)))
 			{
-			    if (cptr->drcc_flags & DRC_TRIGGER)
+			    if (trigpending)
 				cptr = cptr->drcc_next;
 			    continue;
 			}
@@ -1011,12 +1058,7 @@ checkbottom:
 		    DRCstatSlow++;
 		    arg->dCD_cptr = cptr;
 		    TTMaskCom2(&tmpMask, &cptr->drcc_mask);
-		    if (cptr->drcc_flags & DRC_CATECORNER)
-		    {
-			/* (to be done) */
-		    }
-		    else 
-			result = DBSrPaintArea((Tile *) NULL,
+		    result = DBSrPaintArea((Tile *) NULL,
 				arg->dCD_celldef->cd_planes[cptr->drcc_plane],
 				&errRect, &tmpMask, areaCheck, (ClientData) arg);
 
@@ -1025,7 +1067,7 @@ checkbottom:
 		        /* Trigger rule:  If rule check found errors,	*/
 		        /* do the next rule.  Otherwise, skip it.	*/
 
-			if (cptr->drcc_flags & DRC_TRIGGER)
+			if (trigpending)
 			    cptr = cptr->drcc_next;
 		    }
 		}
