@@ -425,7 +425,7 @@ DRCTechAddRule(sectionName, argc, argv)
     "layers1 layers2 distance why",
 	"rect_only",	 3,	3,	drcRectOnly,
     "layers why",
-	"spacing",	 6,	6,	drcSpacing,
+	"spacing",	 6,	7,	drcSpacing,
     "layers1 layers2 separation adjacency why",
 	"stepsize",	 2,	2,	drcStepSize,
     "step_size",
@@ -668,8 +668,8 @@ drcArea(argc, argv)
  * nothing), the new routine is used.
  *
  *	maxwidth metal1 389 "metal1 width > 35um must be slotted"
- *	maxwidth pmc 4 bend_illegal "poly contact area must be at least 4"
- *	maxwidth trench 4 bend_ok "poly contact area must be at least 4"
+ *	maxwidth pmc 4 bend_illegal "poly contact must be no wider than 4"
+ *	maxwidth trench 4 bend_ok "trench width must be exactly 4"
  *
  *      bend_illegal - means that one_dimension must be distance for any 
  *  		point in the region.  This is used for emitters and contacts
@@ -721,7 +721,7 @@ drcMaxwidth(argc, argv)
 	return (0);
     }
 
-    if (argc == 3)
+    if (argc == 4)
     {
 	bend = DRC_BENDS;
 	why = drcWhyDup(argv[3]);
@@ -780,10 +780,6 @@ drcMaxwidth(argc, argv)
  *
  *	spacing layers1 layers2 distance adjacency why
  *
- * or (added 3/28/05)
- *
- *	spacing layers1 layers2 distance catecorner dist2 why
- *
  * e.g,
  *
  *	spacing metal,pmc/m,dmc/m metal,pmc/m,dmc/m 4 touching_ok \
@@ -794,16 +790,6 @@ drcMaxwidth(argc, argv)
  * immediately adjacent to types in layers2.  In the second case,
  * such adjacency causes a violation.
  *
- * The "catecorner" option is designed for two purposes: 1) to catch
- * rule violations that are caused by a cifoutput grow rules followed
- * by a shrink rule.  If a tile is in the catecorner position between
- * distances (G-W) and G, where G is the amount grown, and W is the
- * minimum width of the CIF layer, then a strip of less than W would
- * result, and is therefore a DRC violation.  2) with dist2=0, can be
- * used to indicate that a layer can have no outside corners; that is,
- * corners must be beveled with a non-manhattan (usually 45 degree)
- * angle.
- *
  * Results:
  *	Returns distance.
  *
@@ -841,23 +827,21 @@ drcSpacing(argc, argv)
     char *adjacency;
     char *why;
     TileTypeBitMask set1, set2, tmp1, tmp2, setR, setRreverse;
-    int plane,curPlane, planes1, planes2;
+    int plane, curPlane;
+    PlaneMask planes1, planes2;
     DRCCookie *dp, *dpnew;
     int needReverse = FALSE;
     TileType i, j;
-
+    bool widerule = (strncmp(argv[0], "wide", 4) == 0);
     int wwidth;
-    bool widerule;
-    bool catecorner = FALSE;
 
-    if (argc == 7)
+    if (widerule)
     {
 	wwidth = atoi(argv[2]);
 	layers2 = argv[3];
 	distance = atoi(argv[4]);
 	adjacency = argv[5];
 	why = drcWhyDup(argv[6]);
-	widerule = TRUE;
 	needReverse = TRUE;	/* Requires checks in both directions! */
 	/* TxPrintf("Info:  DRCtech:  widespacing rule for %s width %d:"
 		" spacing must be %d\n", layers1, wwidth, distance); */
@@ -867,14 +851,13 @@ drcSpacing(argc, argv)
 	layers2 = argv[2];
 	distance = atoi(argv[3]);
 	adjacency = argv[4];
-	why = drcWhyDup(argv[5]);
 	wwidth = distance;
-	if (!strcmp(adjacency, "catecorner"))
+	why = drcWhyDup(argv[5]);
+	if (argc == 7)
 	{
-	    wwidth = atoi(argv[5]);
-	    catecorner = TRUE;
+	    TechError("Unknown argument in spacing line.\n");
+	    return(0);
 	}
-	widerule = FALSE;
     }
 
     DBTechNoisyNameMask(layers1, &set1);
@@ -905,16 +888,12 @@ drcSpacing(argc, argv)
 	    break;
     }
 
-    if (!strcmp(adjacency, "touching_ok") || catecorner)
+    if (!strcmp(adjacency, "touching_ok"))
     {
 	/* If touching is OK, everything must fall in the same plane. */
 	if (plane == DBNumPlanes)
 	{
-	    if (catecorner)
-	        TechError("Catecorner spacing check must have"
-			" all types in one plane.\n");
-	    else
-		TechError("Spacing check with touching ok must have"
+	    TechError("Spacing check with touching ok must have"
 			" all types in one plane.\n");
 	    return (0);
 	}
@@ -1017,8 +996,8 @@ drcSpacing(argc, argv)
 			dptrig = (DRCCookie *) mallocMagic((unsigned)
 				(sizeof (DRCCookie)));
 		        ASSIGN(dptrig, wwidth, dpnew, set1, set1, why,
-				wwidth, DRC_REVERSE | DRC_MAXWIDTH | DRC_TRIGGER,
-				curPlane);
+				wwidth, DRC_REVERSE | DRC_MAXWIDTH |
+					DRC_TRIGGER | DRC_BENDS, curPlane);
 
 			dp->drcc_next = dptrig;
 		    }
@@ -1044,9 +1023,6 @@ drcSpacing(argc, argv)
 		    if (needReverse)
 		        dpnew->drcc_flags |= DRC_BOTHCORNERS;
 
-		    if (catecorner)
-			dpnew->drcc_flags |= DRC_CATECORNER;
-
 		    if (needReverse)
 		    {
 			/* Add check in reverse direction, 
@@ -1071,8 +1047,8 @@ drcSpacing(argc, argv)
 			    dptrig = (DRCCookie *) mallocMagic((unsigned)
 				(sizeof (DRCCookie)));
 			    ASSIGN(dptrig, wwidth, dpnew, set1, set1, why,
-				wwidth, DRC_FORWARD | DRC_MAXWIDTH | DRC_TRIGGER,
-				curPlane);
+				wwidth, DRC_FORWARD | DRC_MAXWIDTH |
+					DRC_TRIGGER | DRC_BENDS, curPlane);
 			    dp->drcc_next = dptrig;
 			}
 			else
@@ -1126,9 +1102,6 @@ drcSpacing(argc, argv)
 		    if (needReverse)
 		        dpnew->drcc_flags |= DRC_BOTHCORNERS;
 
-		    if (catecorner)
-			dpnew->drcc_flags |= DRC_CATECORNER;
-
 		    dp->drcc_next = dpnew;		    
 
 		    if (needReverse)
@@ -1258,7 +1231,8 @@ drcEdge(argc, argv)
     bool fourway = (strcmp(argv[0], "edge4way") == 0);
     TileTypeBitMask set1, set2, tmp1, tmp2, tmp3, setC, setM;
     DRCCookie *dp, *dpnew;
-    int plane, checkPlane, pMask, tmpPlane;
+    int plane, checkPlane, tmpPlane;
+    PlaneMask pMask;
     TileType i, j;
 
     /*
