@@ -31,9 +31,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/extf
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
-#ifdef SYSV
 #include <string.h>
-#endif
 
 #include "utils/magic.h"
 #include "utils/geometry.h"
