@@ -266,7 +266,8 @@ extBasicOverlap(tile, ecs)
     extCapStruct *ecs;
 {
     int thisType;
-    int pNum, pMask;
+    int pNum;
+    PlaneMask pMask;
     TileTypeBitMask *tMask;
     Rect r;
     CellDef *def = ecs->def;
@@ -341,7 +342,7 @@ struct overlap
 {
     Rect		 o_clip;
     int			 o_area;
-    int			 o_pmask;
+    PlaneMask		 o_pmask;
     TileTypeBitMask	 o_tmask;
 };
 
@@ -599,7 +600,9 @@ extAddCouple(bp, ecs)
     extCapStruct *ecs;
 {
     TileType tin = TiGetType(bp->b_inside), tout = TiGetType(bp->b_outside);
-    int pNum, pMask, (*proc)();
+    int pNum;
+    PlaneMask pMask;
+    int (*proc)();
     Boundary bpCopy;
     Rect r, ovr;
     CellDef *def = ecs->def;
