@@ -20,12 +20,13 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtHier.c,v 1.5 2001/07/23 17:49:52 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/extract/ExtHier.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <math.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -33,7 +34,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtHier.c,v 1.5 20
 #include "database/database.h"
 #include "utils/malloc.h"
 #include "textio/textio.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 #include "debug/debug.h"
@@ -399,8 +400,8 @@ extOutputConns(table, outf)
 		/* Subsequent merges */
 		for (nn = nnext; nnext = nn->nn_next; nn = nnext)
 		{
-		    fprintf(outf, "merge \"%s\" \"%s\" %lg\n",
-				    nn->nn_name, nnext->nn_name, c);
+		    fprintf(outf, "merge \"%s\" \"%s\"\n",
+				    nn->nn_name, nnext->nn_name);
 		    nn->nn_node = (Node *) NULL;	/* Processed */
 		}
 	    }
