@@ -17,19 +17,20 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtTimes.c,v 1.4 2001/07/23 17:49:52 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/extract/ExtTimes.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <string.h>
 #include <sys/types.h>
 #include <sys/time.h>
 #include <sys/resource.h>
 #ifdef SYSV
-#include <string.h>
 #include <sys/param.h>
 #include <sys/times.h>
 #endif
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/utils.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
