@@ -16,7 +16,7 @@
  *     *********************************************************************
  *
  *
- * rcsid "$Header: /ufs/repository/magic/graphics/graphicsInt.h,v 1.3 2001/03/29 19:50:10 tim Exp $"
+ * rcsid "$Header: /usr/cvsroot/magic/graphics/graphicsInt.h,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $"
  */
 
 #ifndef _GRAPHICSINT_H
@@ -33,6 +33,7 @@ extern int grBitPlaneMask;
 extern void (*grPutTextPtr)();
 extern void (*grSetSPatternPtr)();
 extern void (*grDefineCursorPtr)();
+extern void (*grFreeCursorPtr)();
 extern bool (*grDrawGridPtr)();
 extern void (*grDrawLinePtr)();
 extern void (*grSetWMandCPtr)();
@@ -49,8 +50,6 @@ extern void grSimpleLock(), grSimpleUnlock();
 extern void grNoLock();
 #define	GR_CHECK_LOCK()	{if (grLockedWindow == NULL) grNoLock();} 
 
-#define GR_NUM_STIPPLES	32
-
 /* The size of the crosses drawn for degenerate box outlines: */
 #define GR_CROSSSIZE 3
 
@@ -76,22 +75,24 @@ extern char *grCursorType;
  */
 extern int grCurDStyle;
 
-/* Device-dependent limit on # of stipples (must be <= GR_NUM_STIPPLES): */
-
-extern int grMaxStipples;
+/* Number of stipples in the style file */
+extern int grNumStipples;
 
 /* Used to setup current color, etc. */
 extern bool grDriverInformed;
 extern void grInformDriver();
 
 /* Macro to check for a bogusly small grid. 
- * Turn off grid if there are more than GR_NUMGRIDS gridlines on the
+ * Turn off grid if there are more than GR_NUM_GRIDS gridlines on the
  * screen in either direction, or if they are less than 4 pixels apart.
  */
 #define GR_NUM_GRIDS 160
 #define GRID_TOO_SMALL(x,y,max) ( \
-     ((((GrScreenRect.r_xtop - GrScreenRect.r_xbot) << 12) / (x)) >= (max)) || \
-     ((((GrScreenRect.r_ytop - GrScreenRect.r_ybot) << 12) / (y)) >= (max)) || \
-     (((x) >> 12) < 4) || (((y) >> 12) < 4) )
+     ((((GrScreenRect.r_xtop - GrScreenRect.r_xbot) << SUBPIXELBITS) / (x)) \
+     >= (max)) || \
+     ((((GrScreenRect.r_ytop - GrScreenRect.r_ybot) << SUBPIXELBITS) / (y)) \
+     >= (max)) || \
+     (((x) >> SUBPIXELBITS) < 4) || (((y) >> SUBPIXELBITS) < 4) \
+)
 
 #endif /* _GRAPHICSINT_H */
