@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/irouter/irRoute.c,v 1.2 2001/01/12 22:12:53 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/irouter/irRoute.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 /* --- Includes --- */
@@ -26,7 +26,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/irouter/irRoute.c,v 1.2 20
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
 #include "tiles/tile.h"
@@ -34,14 +34,13 @@ static char rcsid[] = "$Header: /ufs/repository/magic/irouter/irRoute.c,v 1.2 20
 #include "drc/drc.h"
 #include "textio/textio.h"
 #include "windows/windows.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "dbwind/dbwind.h"
 #include "debug/debug.h"
-#include "undo/undo.h"
-#include "signals/signals.h"
+#include "utils/undo.h"
+#include "utils/signals.h"
 #include "utils/malloc.h"
 #include "utils/list.h"
-#include "utils/doubleint.h"
 #include "utils/geofast.h"
 #include "utils/touchingtypes.h"
 #include "select/select.h"
