@@ -6,24 +6,22 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/lef/lefCmd.c,v 1.0 2003/05/01 10:54:00 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/lef/lefCmd.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef SYSV
 #include <string.h>
-#endif
 
-#include "magic/tclmagic.h"
-#include "misc/magic.h"
+#include "tcltk/tclmagic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "textio/txcommands.h"
 #include "commands/commands.h"
 
@@ -68,13 +66,38 @@ CmdLef(w, cmd)
     CellUse *selectedUse;
     CellDef *selectedDef;
     bool is_lef;
+    bool lefImport = FALSE;		/* Indicates whether or not we
+					 * read cells from .mag files
+					 * when the FOREIGN statement
+					 * is encountered in a macro.
+					 */
+    bool lefTopCell = TRUE;		/* Indicates whether or not we
+					 * write the top-level cell to
+					 * LEF, or just the subcells.
+					 */
+    bool allSpecial = FALSE;		/* Indicates whether we should
+					 * treat all geometry as "special"
+					 * nets in DEF format output.
+					 */
 
     static char *cmdLefOption[] =
     {	
-	"read [filename]	read a file filename[.lef|.def]",
-	"write [cell]		write current or indicated cell",
-	"writeall		write all cells from the top-level cell",
-	"help                   print this help information",
+	"read [filename]		read a LEF file filename[.lef]\n"
+	"    read [filename] -import	read a LEF file; import cells from .mag files",
+	"write [cell]			write LEF for current or indicated cell",
+	"writeall			write all cells including the top-level cell\n"
+	"    writeall -notop		write all subcells of the top-level cell",
+	"help                   	print this help information",
+	NULL
+    };
+
+    static char *cmdDefOption[] =
+    {	
+	"read [filename]		read a DEF file filename[.def]",
+	"write [cell] [-allspecial]	write DEF for current or indicated cell",
+	"writeall			(use \"flatten -nosubckt\" + \"def"
+					" write\" instead)",
+	"help                   	print this help information",
 	NULL
     };
 
@@ -117,26 +140,56 @@ CmdLef(w, cmd)
     switch (option)
     {
 	case LEF_READ:
-            if (cmd->tx_argc != 3) goto wrongNumArgs;
+            if (cmd->tx_argc != 3)
+	    {
+		if (cmd->tx_argc == 4)
+		{
+		    if (*(cmd->tx_argv[3]) == '-')
+			if (!strncmp(cmd->tx_argv[3], "-import", 7))
+			    lefImport = TRUE;
+		}
+		else
+		    goto wrongNumArgs;
+	    }
             namep = cmd->tx_argv[2];
 	    if (is_lef)
-		LefRead(namep);
+		LefRead(namep, lefImport);
 	    else
 		DefRead(namep);
 	    break;
 	case LEF_WRITEALL:
 	    if (!is_lef)
-		TxError("Sorry, can't write DEF files at this time.\n");
+	    {
+		TxError("Sorry, can't write hierarchical DEF at this time.\n");
+		TxError("Try \"def write\"\n");
+	    }
 	    else
-		LefWriteAll(selectedUse);
+	    {
+		if (cmd->tx_argc == 3)
+		    if (*(cmd->tx_argv[2]) == '-')
+			if (!strncmp(cmd->tx_argv[2], "-notop", 6))
+			    lefTopCell = FALSE;
+
+		LefWriteAll(selectedUse, lefTopCell);
+	    }
 	    break;
 	case LEF_WRITE:
 	    if (!is_lef)
 	    {
-		TxError("Sorry, can't write DEF files at this time.\n");
-		return;
+		allSpecial = FALSE;
+		if (cmd->tx_argc == 4)
+		{
+		    if (*(cmd->tx_argv[3]) == '-')
+		    {
+			if (!strncmp(cmd->tx_argv[3], "-allspec", 8))
+			    allSpecial = TRUE;
+			else goto wrongNumArgs;
+		    }
+		    else goto wrongNumArgs;
+		}
+		else if (cmd->tx_argc != 3) goto wrongNumArgs;
 	    }
-            if (cmd->tx_argc != 3) goto wrongNumArgs;
+            else if (cmd->tx_argc != 3) goto wrongNumArgs;
             namep = cmd->tx_argv[2];
             selectedUse = CmdGetSelectedCell((Transform *) NULL);
             if (selectedUse == NULL)
@@ -144,13 +197,17 @@ CmdLef(w, cmd)
                 TxError("No cell selected\n");
                 return;
             }
-            LefWriteCell(selectedUse->cu_def, namep, selectedUse->cu_def
-		== EditRootDef);
+	    if (!is_lef)
+		DefWriteCell(selectedUse->cu_def, namep, allSpecial);
+	    else
+		LefWriteCell(selectedUse->cu_def, namep, selectedUse->cu_def
+			== EditRootDef);
 	    break;
 	case LEF_HELP:
 wrongNumArgs:
 	    TxPrintf("The \"%s\" options are:\n", cmd->tx_argv[0]);
-	    for (msg = &(cmdLefOption[0]); *msg != NULL; msg++)
+	    msg = (is_lef) ? &(cmdLefOption[0]) : &(cmdDefOption[0]);
+	    for (; *msg != NULL; msg++)
 	    {
 		TxPrintf("    %s %s\n", cmd->tx_argv[0], *msg);
 	    }
