@@ -21,17 +21,15 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/lef/lefRead.c,v 1.0 2003/05/01 10:37:00 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/lef/lefTech.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef SYSV
 #include <string.h>
-#endif
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -40,7 +38,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/lef/lefRead.c,v 1.0 2003/0
 #include "lef/lefInt.h"
 #include "drc/drc.h"
 
-/* ---------------------------------------------------------------------
+/* ---------------------------------------------------------------------*/
 
 /* Layer and Via routing information table.  */
 
@@ -100,13 +98,14 @@ LefTechInit()
 	while (he = HashNext(&LefInfo, &hs))
 	{
 	    lefl = (lefLayer *)HashGetValue(he);
+	    if (!lefl) continue;
 	    lefl->refCnt--;
 	    if (lefl->refCnt <= 0)
 	    {
 		/* Via detailed information, if it exists,	*/
 		/* needs to have its allocated memory free'd.	*/
 
-		if (lefl->is_via)
+		if (lefl->lefClass == CLASS_VIA)
 		    if (lefl->info.via.lr != NULL)
 			freeMagic(lefl->info.via.lr);
 
@@ -118,6 +117,51 @@ LefTechInit()
     HashInit(&LefInfo, 32, HT_STRINGKEYS);
 }
 
+/*
+ *-----------------------------------------------------------------------------
+ * lefRemoveGeneratedVias --
+ *
+ *	Remove the Generated Vias created during a DEF file write
+ *	from the LEF layer hash table.  By design, each of these
+ *	generated layers gets a refCnt of zero, so they are easy
+ *	to find.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Memory freed in the hash table.
+ * 
+ *-----------------------------------------------------------------------------
+ */
+
+void
+lefRemoveGeneratedVias()
+{
+    HashSearch hs;
+    HashEntry *he;
+    lefLayer *lefl;
+
+    if (LefInfo.ht_table != (HashEntry **) NULL)
+    {
+	HashStartSearch(&hs);
+	while (he = HashNext(&LefInfo, &hs))
+	{
+	    lefl = (lefLayer *)HashGetValue(he);
+	    if (!lefl) continue;
+	    if (lefl->refCnt == 0)
+	    {
+		if (lefl->lefClass == CLASS_VIA)
+		    if (lefl->info.via.lr != NULL)
+			freeMagic(lefl->info.via.lr);
+
+		freeMagic(lefl);
+		HashSetValue(he, NULL);
+	    }
+	}
+    }
+}
+
 /*
  *-----------------------------------------------------------------------------
  *  LefTechLine --
@@ -134,6 +178,14 @@ LefTechInit()
  * ----------------------------------------------------------------------------
  */
 
+#define LEFTECH_OBS	0
+#define LEFTECH_LAYER	1
+#define LEFTECH_ROUTE	2
+#define LEFTECH_ROUTING 3
+#define LEFTECH_MASTER	4
+#define LEFTECH_CUT	5
+#define LEFTECH_OVERLAP 6
+
 bool
 LefTechLine(sectionName, argc, argv)
     char *sectionName;          /* Name of this section (unused). */
@@ -144,17 +196,11 @@ LefTechLine(sectionName, argc, argv)
     HashEntry *he;
     TileType mtype;
     lefLayer *lefl, *newlefl;
-    int i;
-
-    if (!strncmp(argv[0], "obs", 3))
-	isObstruction = TRUE;
-    else if (!strncmp(argv[0], "layer", 5))
-	isObstruction = FALSE;
-    else
-    {
-        TechError("Unknown LEF section keyword: %s.  Line ignored.\n", argv[0]);
-        return TRUE;
-    }
+    int i, option;
+    static char *keywords[] = {
+	"obstruction", "layer", "route", "routing", "masterslice",
+	"cut", "overlap", NULL
+    };
 
     if (argc < 3)
     {
@@ -162,9 +208,34 @@ LefTechLine(sectionName, argc, argv)
 	return TRUE;
     }
 
+    option = Lookup(argv[0], keywords);
+    if (option < 0)
+    {
+        TechError("Unknown LEF section keyword: %s.  Line ignored.\n", argv[0]);
+        return TRUE;
+    }
+
+    switch (option)
+    {
+	case LEFTECH_OBS:
+	    isObstruction = TRUE;
+	    break;
+	default:
+	    isObstruction = FALSE;
+    }
+
     mtype = DBTechNoisyNameType(argv[1]);
     if (mtype < 0) return TRUE;
+
     isContact = DBIsContact(mtype);
+    if (option == LEFTECH_LAYER)
+	option = (isContact) ? LEFTECH_CUT : LEFTECH_ROUTE;
+    else if (isContact && (option != LEFTECH_CUT))
+        TechError("Attempt to define cut type %s as %s.\n",
+		DBTypeLongNameTbl[mtype], keywords[option]);
+    else if (!isContact && (option == LEFTECH_CUT))
+        TechError("Attempt to define non-cut type %s as a cut.\n",
+		DBTypeLongNameTbl[mtype]);
 
     /* All other aliases are stuffed in the hash table but point to the	*/
     /* same record as the first.  If any name is repeated, then report	*/
@@ -181,6 +252,8 @@ LefTechLine(sectionName, argc, argv)
 
 	    if (newlefl == NULL)
 	    {
+		float oscale = CIFGetOutputScale(1000);
+
 		newlefl = (lefLayer *)mallocMagic(sizeof(lefLayer));
 		newlefl->refCnt = 0;
 		newlefl->type = -1;
@@ -190,28 +263,40 @@ LefTechLine(sectionName, argc, argv)
 		else
 		   newlefl->type = mtype;
 
-		newlefl->is_via = isContact;
+		newlefl->canonName = (char *)he->h_key.h_name;
 
-		/* Fill in default values for type */
-		if (isContact)
+		/* Fill in default values per type */
+
+		switch (option)
 		{
-		    newlefl->info.via.area = GeoNullRect;
-		    newlefl->info.via.cell = (CellDef *)NULL;
-		    newlefl->info.via.lr = (linkedRect *)NULL;
-		}
-		else
-		{
-		    float oscale = CIFGetOutputScale(1000);
-		    newlefl->info.route.width = DRCGetDefaultLayerWidth(mtype);
-		    if (newlefl->info.route.width == 0)
-			newlefl->info.route.width = DEFAULT_WIDTH;
-		    newlefl->info.route.spacing = DRCGetDefaultLayerSpacing(mtype,
-				mtype);
-		    if (newlefl->info.route.spacing == 0)
-			newlefl->info.route.spacing = DEFAULT_SPACING;
-		    newlefl->info.route.pitch = 0;
-		    newlefl->info.route.hdirection = TRUE;
+		    case LEFTECH_CUT:
+			newlefl->lefClass = CLASS_VIA;
+			newlefl->info.via.area = GeoNullRect;
+			newlefl->info.via.cell = (CellDef *)NULL;
+			newlefl->info.via.lr = (linkedRect *)NULL;
+			break;
+		    case LEFTECH_ROUTE:
+		    case LEFTECH_ROUTING:
+		    case LEFTECH_OBS:
+			newlefl->lefClass = CLASS_ROUTE;
+			newlefl->info.route.width = DRCGetDefaultLayerWidth(mtype);
+			if (newlefl->info.route.width == 0)
+			    newlefl->info.route.width = DEFAULT_WIDTH;
+			newlefl->info.route.spacing = DRCGetDefaultLayerSpacing(mtype,
+					mtype);
+			if (newlefl->info.route.spacing == 0)
+			    newlefl->info.route.spacing = DEFAULT_SPACING;
+			newlefl->info.route.pitch = 0;
+			newlefl->info.route.hdirection = TRUE;
+			break;
+		    case LEFTECH_MASTER:
+			newlefl->lefClass = CLASS_MASTER;
+			break;
+		    case LEFTECH_OVERLAP:
+			newlefl->lefClass = CLASS_OVERLAP;
+			break;
 		}
+
 	    }
 	    HashSetValue(he, newlefl);
 	    newlefl->refCnt++;
@@ -264,20 +349,36 @@ LefTechScale(scalen, scaled)
 	while (he = HashNext(&LefInfo, &hs))
 	{
 	    lefl = (lefLayer *)HashGetValue(he);
-	    if (lefl->is_via)
+	    if (!lefl) continue;
+	    if (lefl->refCnt >= 1)
 	    {
-		DBScalePoint(&lefl->info.via.area.r_ll, scalen, scaled);
-		DBScalePoint(&lefl->info.via.area.r_ur, scalen, scaled);
-	    }
-	    else
-	    {
-		lefl->info.route.width *= scalen;
-		lefl->info.route.width /= scaled;
-		lefl->info.route.spacing *= scalen;
-		lefl->info.route.spacing /= scaled;
-		lefl->info.route.pitch *= scalen;
-		lefl->info.route.pitch /= scaled;
+		/* Avoid scaling more than once. . . */
+		if (lefl->refCnt > 1) lefl->refCnt = -lefl->refCnt;
+		if (lefl->lefClass == CLASS_VIA)
+		{
+		    DBScalePoint(&lefl->info.via.area.r_ll, scalen, scaled);
+		    DBScalePoint(&lefl->info.via.area.r_ur, scalen, scaled);
+		}
+		else if (lefl->lefClass == CLASS_ROUTE)
+		{
+		    lefl->info.route.width *= scalen;
+		    lefl->info.route.width /= scaled;
+		    lefl->info.route.spacing *= scalen;
+		    lefl->info.route.spacing /= scaled;
+		    lefl->info.route.pitch *= scalen;
+		    lefl->info.route.pitch /= scaled;
+		}
 	    }
 	}
+
+	/* Return all refCnt values to normal */
+	HashStartSearch(&hs);
+	while (he = HashNext(&LefInfo, &hs))
+	{
+	    lefl = (lefLayer *)HashGetValue(he);
+	    if (!lefl) continue;
+	    if (lefl->refCnt < 0)
+		lefl->refCnt = -lefl->refCnt;
+	}
     }
 }
