@@ -18,12 +18,13 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$$";
+static char rcsid[] __attribute__ ((unused)) = "$$";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
-#include "signals/signals.h"
+
+#include "utils/magic.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "utils/hash.h"
 #include "utils/geometry.h"
@@ -31,7 +32,6 @@ static char rcsid[] = "$$";
 #include "database/database.h"
 #include "utils/malloc.h"
 #include "utils/list.h"
-#include "utils/doubleint.h"
 #include "utils/heap.h"
 #include "mzrouter/mzrouter.h"
 #include "mzrouter/mzInternal.h"
@@ -383,7 +383,7 @@ mzPrintRP(path)
 	DBTypeLongNameTbl[path->rp_rLayer->rl_routeType.rt_tileType]);
     TxPrintf(" entry = (%d, %d)", path->rp_entry.p_x, path->rp_entry.p_y);
     TxPrintf(" cost = %.0f", 
-	     DoubleToDFloat(path->rp_cost));
+	    							 (double)(path->rp_cost));
     TxPrintf(" extCode = { ");
     if (path->rp_extendCode & EC_RIGHT)
     {
@@ -429,9 +429,9 @@ mzPrintPathHead(path)
 		 DBTypeLongNameTbl[path->rp_rLayer->rl_routeType.rt_tileType],
 		 path->rp_orient);
 	TxPrintf(", togo=%.0f",
-		 DoubleToDFloat(path->rp_togo));
+		 									(double)(path->rp_togo));
 	TxPrintf(", cost=%.0f\n",
-		 DoubleToDFloat(path->rp_cost));
+		 (double)(path->rp_cost));
 
 	TxPrintf("    extendCode = { ");
 	if (path->rp_extendCode & EC_RIGHT)
