@@ -123,24 +123,24 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/mzrouter/mzSearch.c,v 1.2 2001/01/12 22:13:02 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/mzrouter/mzSearch.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
-#include "utils/doubleint.h"
 #include "utils/hash.h"
 #include "utils/heap.h"
-#include "../tiles/tile.h"
+#include "tiles/tile.h"
 #include "database/database.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "utils/malloc.h"
 #include "utils/list.h"
 #include "debug/debug.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 #include "mzrouter/mzrouter.h"
@@ -183,7 +183,7 @@ extern void mzStartDown();
  *
  * ----------------------------------------------------------------------------
  */
-
+/* BY NP */
 RoutePath *
 mzSearch()
 {
@@ -196,20 +196,16 @@ mzSearch()
     if(mzVerbosity>=VERB_STATS)
     {
 	TxPrintf("Initial Cost Estimate:   %.0f\n",
-		 DoubleToDFloat(mzInitialEstimate));
+		(double)(mzInitialEstimate));
     }
 
     if (DebugIsSet(mzDebugID, mzDebMaze))
     {
 	TxPrintf("\nBEGINNING SEARCH.\n");
-	TxPrintf("\tmzWRate = %.0f\n", 
-		 DoubleToDFloat(mzWRate));
-	TxPrintf("\tmzWInitialMinToGo = %.0f\n", 
-		 DoubleToDFloat(mzWInitialMinToGo));
-	TxPrintf("\tmzWInitialMaxToGo = %.0f\n", 
-		 DoubleToDFloat(mzWInitialMaxToGo));
-	TxPrintf("\tmzBloomDeltaCost = %.0f\n",
-		 DoubleToDFloat(mzBloomDeltaCost));
+	TxPrintf("\tmzWRate = %.0f\n", (double)(mzWRate));
+	TxPrintf("\tmzWInitialMinToGo = %.0f\n", (double)(mzWInitialMinToGo));
+	TxPrintf("\tmzWInitialMaxToGo = %.0f\n", (double)(mzWInitialMaxToGo));
+	TxPrintf("\tmzBloomDeltaCost = %.0f\n", (double)(mzBloomDeltaCost));
     }
 
     while (morePartialPaths && 
@@ -426,49 +422,49 @@ mzSearch()
 
 	    /* set window thresholds */
 	    {
-		DoubleInt offset;
+		dlong offset;
 
-		offset = DoubleMultI(mzWRate, mzNumBlooms);
+		offset = (dlong) (mzWRate * mzNumBlooms);
 
-		if(DOUBLE_LE(offset, mzWInitialMinToGo))
+		if(offset <= mzWInitialMinToGo)
 		{
-		    DOUBLE_SUB(mzWindowMinToGo, mzWInitialMinToGo, offset);
+		    mzWindowMinToGo =  mzWInitialMinToGo - offset;
 		}
 		else
 		{
-		    mzWindowMinToGo = DIZero;
+		    mzWindowMinToGo = 0;
 		}
 
-		if(DOUBLE_LE(offset, mzWInitialMaxToGo))
+		if(offset <= mzWInitialMaxToGo)
 		{
-		    DOUBLE_SUB(mzWindowMaxToGo, mzWInitialMaxToGo, offset);
+		    mzWindowMaxToGo = mzWInitialMaxToGo - offset;
 		}
 		else
 		{
-		    mzWindowMaxToGo = DIZero;
+		    mzWindowMaxToGo = 0;
 		}
 
 	        if (DebugIsSet(mzDebugID, mzDebMaze))
 	        {
 		    TxPrintf("New window thresholds:  ");
                     TxPrintf("windowMinToGo = %.0f, ",
-			     DoubleToDFloat(mzWindowMinToGo));
+													     (double)mzWindowMinToGo);
 		    TxPrintf("windowMaxToGo = %.0f\n ",
-			     DoubleToDFloat(mzWindowMaxToGo));
+													     (double)mzWindowMaxToGo);
   	        }
 	    }
 
 	    /* If window sweep is complete, and a complete path
 	     * has been found, stop searching.
 	     */
-	    if(DOUBLE_EQUAL(mzWindowMaxToGo, DIZero) && 
+	    if((mzWindowMaxToGo == 0) &&
 	       HeapLookAtTop(&mzMinCostCompleteHeap))
 	    {
 	        if (DebugIsSet(mzDebugID, mzDebMaze))
 	        {
 		    TxPrintf("WINDOW SWEEP DONE AND COMPLETE PATH EXISTS.");
 		    TxPrintf("  Stop searching.\n");
-  	        }
+		}
 
 		windowSweepDoneAndCompletePathFound = TRUE;
 		continue;
@@ -485,10 +481,8 @@ mzSearch()
 		}
 
 		while((maxToGoTop=HeapRemoveTop(&mzMaxToGoHeap,
-						  &maxToGoTopBuf)) != NULL
-		      && 
-		      DOUBLE_GE(maxToGoTop->he_union.hu_dint, 
-				mzWindowMinToGo))
+			  &maxToGoTopBuf)) != NULL && 
+		      (maxToGoTop->he_union.hu_dint >= mzWindowMinToGo))
 		{
 		    if (DebugIsSet(mzDebugID, mzDebMaze))
 		    {
@@ -519,30 +513,26 @@ mzSearch()
 		}
 
 		while((minCostTop=HeapRemoveTop(&mzMinCostHeap,
-						  &minCostTopBuf))!=NULL 
-		      &&
-		      DOUBLE_GREATER(((RoutePath *)(minCostTop->he_id))
-				     ->rp_togo,mzWindowMaxToGo))
+			&minCostTopBuf))!=NULL &&
+			(((RoutePath *)(minCostTop->he_id))->rp_togo >
+			mzWindowMaxToGo))
 		{
-		    DoubleInt adjCost;
+		    dlong adjCost;
 
 		    /* compute adjusted cost */
-		    adjCost = ((RoutePath *)(minCostTop->he_id))->rp_togo;
-		    adjCost = DoubleMultI(adjCost, mzPenalty.rf_mantissa);
-		    DOUBLE_SHIFTRIGHT(adjCost, adjCost, 
-				      mzPenalty.rf_nExponent);
-		    DOUBLE_ADD(adjCost, adjCost, minCostTop->he_union.hu_dint);
+		    adjCost = (dlong)((RoutePath *)(minCostTop->he_id))->rp_togo;
+		    adjCost = (dlong)(adjCost * mzPenalty.rf_mantissa);
+		    adjCost = adjCost >> mzPenalty.rf_nExponent;
+		    adjCost += minCostTop->he_union.hu_dint;
 
 		    if (DebugIsSet(mzDebugID, mzDebMaze))
 		    {
 			mzPrintPathHead((RoutePath*)(minCostTop->he_id));
-			TxPrintf("  Heap-key adjCost = %.0f\n",
-				 DoubleToDFloat(adjCost));
+			TxPrintf("  Heap-key adjCost = %.0f\n", (double)adjCost);
 		    }
 
 		    /* add to adjusted cost heap */
-		    HeapAddDInt(&mzMinAdjCostHeap, 
-			      adjCost,
+		    HeapAddDInt(&mzMinAdjCostHeap, adjCost,
 			      (char *) (minCostTop->he_id));
 		}
 
@@ -587,7 +577,7 @@ mzSearch()
 		if(minAdjCostTop)
 		{
 		    TxPrintf("  Heap-key adjCost:  %.0f\n", 
-			     DoubleToDFloat(minAdjCostTop->he_union.hu_dint));
+			     (double)(minAdjCostTop->he_union.hu_dint));
 		}
 		else
 		{
@@ -602,21 +592,21 @@ mzSearch()
 		 * position (we only penalize for amount toGo exceeding
 		 * mzWindowMaxToGo)
 		 */
-		DoubleInt cost, adjCost;
+		dlong cost, adjCost;
 
-		cost = ((RoutePath *)(minAdjCostTop->he_id))->rp_cost;
-		adjCost = ((RoutePath *)(minAdjCostTop->he_id))->rp_togo;
-		ASSERT(DOUBLE_GE(adjCost, mzWindowMaxToGo),"mzSearch");
-		DOUBLE_SUB(adjCost, adjCost, mzWindowMaxToGo);
-		adjCost = DoubleMultI(adjCost, mzPenalty.rf_mantissa);
-		DOUBLE_SHIFTRIGHT(adjCost, adjCost, mzPenalty.rf_nExponent);
-		DOUBLE_ADD(adjCost, adjCost, cost);
+		cost =(dlong)((RoutePath *)(minAdjCostTop->he_id))->rp_cost;
+		adjCost = (dlong)((RoutePath *)(minAdjCostTop->he_id))->rp_togo;
+		ASSERT(adjCost >= mzWindowMaxToGo,"mzSearch");
+		adjCost -= mzWindowMaxToGo;
+		adjCost *= mzPenalty.rf_mantissa;
+		adjCost = adjCost >> mzPenalty.rf_nExponent;
+		adjCost += cost;
 		if (DebugIsSet(mzDebugID, mzDebMaze))
 		{		
 		    TxPrintf("WINDOW-CORRECTED ADJCOST:  %.0f\n",
-			     DoubleToDFloat(adjCost));
+			 	(double)(adjCost));
 		}
-		if(DOUBLE_LE(minCostTop->he_union.hu_dint, adjCost))
+		if(minCostTop->he_union.hu_dint <= adjCost)
 		{
 		    if (DebugIsSet(mzDebugID, mzDebMaze))
 		    {
@@ -625,7 +615,6 @@ mzSearch()
 		    }
 		    minCostTop = HeapRemoveTop(&mzMinCostHeap, &buf);
 		    mzBloomInit((RoutePath *) (minCostTop->he_id));
-
 		}
 		else
 		{
@@ -637,7 +626,6 @@ mzSearch()
 		    minAdjCostTop = HeapRemoveTop(&mzMinAdjCostHeap, &buf);
 		    mzBloomInit((RoutePath *) (minAdjCostTop->he_id));
 		    mzNumOutsideBlooms++;
-
 		}
 	    }
 	    else if(minCostTop)
@@ -803,7 +791,7 @@ mzExtendPath(path)
  *
  * ----------------------------------------------------------------------------
  */
-
+/* BY NP */
 void
 mzExtendViaContacts(path)
     RoutePath *path;
@@ -855,14 +843,11 @@ mzExtendViaContacts(path)
 
 	/* OK to drop a contact here */
 	{
-	    DoubleInt conCost;
+	    dlong conCost;
 	    int extendCode;
 
 	    /* set contact cost */
-	    {
-		int i = rC->rc_cost;
-		DOUBLE_CREATE(conCost, i);
-	    }
+	    conCost = (dlong) rC->rc_cost;
 
 	    /* determine appropriate extendcode */
 	    {
@@ -873,65 +858,44 @@ mzExtendViaContacts(path)
 		switch (type)
 		{
 		    case TT_SPACE:
-		    {
 			extendCode = EC_RIGHT | EC_LEFT | EC_UP | EC_DOWN;
-		    }
-		    break;
+			break;
 
 		    case TT_LEFT_WALK:
-		    {
 			extendCode = EC_WALKRIGHT;
-		    }
-		    break;
+			break;
 
 		    case TT_RIGHT_WALK:
-		    {
 			extendCode = EC_WALKLEFT;
-		    }
-		    break;
+			break;
 
 		    case TT_TOP_WALK:
-		    {
 			extendCode = EC_WALKDOWN;
-		    }
-		    break;
+			break;
 
 		    case TT_BOTTOM_WALK:
-		    {
 			extendCode = EC_WALKUP;
-		    }
-		    break;
+			break;
 
 		    case TT_CONTACT_WALK:
-		    {
 			/* skip this contact after all, to avoid stacked
 			 * contacts.
 			 */
 			continue;
-		    }
-		    break;
+			break;
 
 		    case TT_DEST_AREA:
-		    {
 			extendCode = EC_COMPLETE;
-		    }
-		    break;
+			break;
 
 		    default:
-		    {
 			/* this shouldn't happen */
 			ASSERT(FALSE,"mzExtendViaContacts");
-		    }
 		}
 	    }
 
 	    /* Finally add point after contact */
-	    mzAddPoint(path, 
-		       p, 
-		       newRLayer, 
-		       'O', 
-		       extendCode,
-		       conCost);
+	    mzAddPoint(path, p, newRLayer, 'O', extendCode, conCost);
 	}
     }
 
@@ -956,37 +920,35 @@ mzExtendViaContacts(path)
  *
  * ----------------------------------------------------------------------------
  */
-
+/* BY NP */
 void
 mzAddPoint(path, p, rLayer, orient, extendCode, cost)
     RoutePath *path;	/* path that new point extends */
     Point *p;		/* new point */
     RouteLayer *rLayer;	/* Route Layer of new point */
-    int orient;	/* 'H' = endpt of hor seg, 'V' = endpt of vert seg, 
+    int orient;		/* 'H' = endpt of hor seg, 'V' = endpt of vert seg, 
 			 * 'O' = contact, 'B' = first point in path and blocked
 			 */
     int extendCode;	/* interesting directions to extend in */
-    DoubleInt cost;	/* Incremental cost of new path segment */
+    dlong cost;		/* Incremental cost of new path segment */
 
 {
     RoutePath *newPath;
     RoutePath *hashedPath;
     HashEntry *he;
     PointKey pk;
-    DoubleInt togo;
+    dlong togo;
 
     /* DEBUG - print candidate frontier point */
     if (DebugIsSet(mzDebugID, mzDebMaze))
     {
-	TxPrintf(
-	    "mzAddPoint called:  point=(%d,%d), layer=%s, orient='%c'\n",
-	    p->p_x,
-	    p->p_y,
-	    DBTypeLongNameTbl[rLayer->rl_routeType.rt_tileType],
-	    orient);
+	TxPrintf("mzAddPoint called:  point=(%d,%d), layer=%s, orient='%c'\n",
+	    	p->p_x, p->p_y,
+	    	DBTypeLongNameTbl[rLayer->rl_routeType.rt_tileType],
+	    	orient);
     }
 
-    ASSERT(DOUBLE_GE(cost,DIZero),"mzAddPoint");
+    ASSERT(cost >= 0,"mzAddPoint");
 
     /* Ignore if outside of bounding box */
     if (!GEO_ENCLOSE(p, &mzBoundingRect))
@@ -994,13 +956,9 @@ mzAddPoint(path, p, rLayer, orient, extendCode, cost)
 
     /* get estimated distance togo */
     if(extendCode == EC_COMPLETE)
-    {
-	togo = DIZero;
-    }
+	togo = 0;
     else
-    {
 	togo = mzEstimatedCost(p);
-    }
 
     /* compute (total) cost for new path */
     {
@@ -1012,7 +970,7 @@ mzAddPoint(path, p, rLayer, orient, extendCode, cost)
 	   path->rp_orient != 'O' &&
 	   path->rp_orient != orient)
 	{
-	    DOUBLE_ADDI(cost, cost, rLayer->rl_jogCost);
+	    cost +=  rLayer->rl_jogCost;
 	}
 
 	/* Add estimated total cost prior to new point, 
@@ -1020,16 +978,16 @@ mzAddPoint(path, p, rLayer, orient, extendCode, cost)
 	 */
 	if(path!=NULL)
 	{
-	    DOUBLE_ADD(cost, cost, path->rp_cost);
+	    cost += path->rp_cost;
 	}
 	/* If not initial path, subtract out old estimated cost togo */
 	if(mzPathSource!=SOURCE_INIT)
 	{
-	    DOUBLE_SUB(cost, cost, path->rp_togo);
+	    cost -= path->rp_togo;
 	}
 
 	/* Add new estimated cost to completion */
-	DOUBLE_ADD(cost, cost, togo);
+	cost += togo;
     }
 
     /* Check hash table to see if cheaper path to this point already
@@ -1041,16 +999,16 @@ mzAddPoint(path, p, rLayer, orient, extendCode, cost)
     he = HashFind(&mzPointHash, (ClientData) &pk);
     hashedPath = (RoutePath *) HashGetValue(he);
 
-    if (hashedPath != NULL
-	&& DOUBLE_LE(hashedPath->rp_cost, cost))
+    if (hashedPath != NULL && (hashedPath->rp_cost <= cost))
     {
 	if (DebugIsSet(mzDebugID, mzDebMaze))
 	{
-	    TxPrintf("new point NOT added, at least as good path to pt already exists:  ");
+	    TxPrintf("new point NOT added, at least as good "
+			"path to pt already exists:  ");
 	    TxPrintf("new cost = %.0f, ",
-		     DoubleToDFloat(cost));
+			(double)(cost));
 	    TxPrintf("cheapest cost = %.0f\n",
-		     DoubleToDFloat(hashedPath->rp_cost));
+			(double)(hashedPath->rp_cost));
 	}
 	return;
     }
@@ -1058,7 +1016,7 @@ mzAddPoint(path, p, rLayer, orient, extendCode, cost)
     /* If initial path, update min initial cost */
     if(mzPathSource==SOURCE_INIT)
     {
-	if(DOUBLE_LESS(cost,mzMinInitialCost))
+	if(cost < mzMinInitialCost)
 	{
 	    mzMinInitialCost = cost;
 	}
@@ -1088,8 +1046,7 @@ mzAddPoint(path, p, rLayer, orient, extendCode, cost)
 	    TxPrintf("PATH COMPLETE (WALKED IN).  Add to complete heap.\n");
 	}
 
-	HeapAddDInt(&mzMinCostCompleteHeap, 
-		  newPath->rp_cost, 
+	HeapAddDInt(&mzMinCostCompleteHeap, newPath->rp_cost, 
 		  (char *) newPath);
 
 	/* compute stats and make completed path report */
@@ -1098,7 +1055,7 @@ mzAddPoint(path, p, rLayer, orient, extendCode, cost)
 	    
 	    if(mzVerbosity>=VERB_STATS)
 	    {
-		DoubleInt cost, excessCost;
+		dlong cost, excessCost;
 		double excessPercent;
 
 		mzMakeStatReport();
@@ -1107,21 +1064,18 @@ mzAddPoint(path, p, rLayer, orient, extendCode, cost)
 		
 
 		cost = newPath->rp_cost;
-		TxPrintf("cst:%.0f, ",
-			 DoubleToDFloat(newPath->rp_cost));
-		if(DOUBLE_LESS(cost, mzInitialEstimate))
+		TxPrintf("cst:%.0f, ", (double)(newPath->rp_cost));
+		if(cost < mzInitialEstimate)
 		{
 		    TxPrintf("(<est)");
 		}
 		else
 		{
-		    DOUBLE_SUB(excessCost, cost, mzInitialEstimate);
-		    excessPercent = 100.0 *
-		    DoubleToDFloat(excessCost)/
-		    DoubleToDFloat(mzInitialEstimate);
+		    excessCost = cost - mzInitialEstimate;
+		    excessPercent = 100.0 * (double)(excessCost)/
+														    (double)(mzInitialEstimate);
 		    
-		    TxPrintf("overrun: %.0f%%",
-			     excessPercent);
+		    TxPrintf("overrun: %.0f%%", excessPercent);
 		}
 
 		TxPrintf("\n");
@@ -1156,7 +1110,7 @@ mzAddPoint(path, p, rLayer, orient, extendCode, cost)
 	    break;
 
 	    case SOURCE_STRAIGHT:
-	    if(path->rp_orient==orient && DOUBLE_LE(cost,mzBloomMaxCost))
+	    if(path->rp_orient==orient && (cost < mzBloomMaxCost))
 	    {
 		/* straight and within bounds, keep going*/
 		LIST_ADD(newPath, mzStraightStack);
@@ -1170,18 +1124,18 @@ mzAddPoint(path, p, rLayer, orient, extendCode, cost)
 
 	    case SOURCE_DOWNHILL:
 	    {
-		DoubleInt oldCostPlusOne;
+		dlong oldCostPlusOne;
 
-		DOUBLE_ADDI(oldCostPlusOne, path->rp_cost, 1);
-		if(DOUBLE_LESS(cost, oldCostPlusOne))
+		oldCostPlusOne = path->rp_cost + 1;
+		if(cost <oldCostPlusOne)
 		{
 		    /* cost within a unit, keep following down hill */
-		    LIST_ADD(newPath, mzDownHillStack);
+	  	    LIST_ADD(newPath, mzDownHillStack);
 		}
 		else
 		{
 		    /* increased cost, add to heaps */
-		    HeapAddDInt(&mzMaxToGoHeap, togo, (char *) newPath);
+	  	    HeapAddDInt(&mzMaxToGoHeap, togo, (char *) newPath);
 		}
 	    }
 	    break;
@@ -1211,7 +1165,7 @@ mzAddPoint(path, p, rLayer, orient, extendCode, cost)
  *
  * ----------------------------------------------------------------------------
  */
-
+/* BY NP*/
 void
 mzBloomInit(path)
     RoutePath *path;	/* path that new point extends */
@@ -1219,7 +1173,7 @@ mzBloomInit(path)
     ASSERT(mzBloomStack==NULL,"mzBloomInit");
 
     LIST_ADD(path, mzBloomStack);
-    DOUBLE_ADD(mzBloomMaxCost, path->rp_cost, mzBloomDeltaCost);
+    mzBloomMaxCost = path->rp_cost + mzBloomDeltaCost;
 
     mzNumBlooms++;
 
@@ -1242,6 +1196,7 @@ mzBloomInit(path)
  * ----------------------------------------------------------------------------
  */
 
+/* BY NP*/
 void
 mzMakeStatReport()
 {
@@ -1249,16 +1204,12 @@ mzMakeStatReport()
     /* if we aren't being verbose, skip this */
     if(mzVerbosity<VERB_STATS) 	return;
 
-    TxPrintf("  Blms:%d(%d)",
-	     mzNumBlooms - mzNumOutsideBlooms,
+    TxPrintf("  Blms:%d(%d)", mzNumBlooms - mzNumOutsideBlooms,
 	     mzNumBlooms);
 
-    TxPrintf("  Wndw:%.0f(%.0f%%)",
-	     DoubleToDFloat(mzWindowMaxToGo),
-	     (100.0*
-	      (1- DoubleToDFloat(mzWindowMaxToGo)/
-	       (DoubleToDFloat(mzInitialEstimate) +
-		DoubleToDFloat(mzWWidth)))));
+    TxPrintf("  Wndw:%.0f(%.0f%%)", (double)(mzWindowMaxToGo),
+	     	(100.0 * (1- (double)(mzWindowMaxToGo)/
+		((double)(mzInitialEstimate) +(double)(mzWWidth)))));
 
     TxPrintf("  Pts:%d(%d)",
 	     mzNumPaths,
@@ -1269,7 +1220,7 @@ mzMakeStatReport()
 	     mzBlockGenArea/mzBlockGenCalls);
 
     TxPrintf("(%.0f/icst)",
-	     mzBlockGenArea/DoubleToDFloat(mzInitialEstimate));
+	     (double)mzBlockGenArea/(double)(mzInitialEstimate));
     
     TxPrintf("\n");
     return;
