@@ -17,18 +17,18 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/netmenu/NMundo.c,v 1.2 2001/01/12 22:13:07 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/netmenu/NMundo.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
 #include "netmenu/netmenu.h"
 #include "netmenu/nmInt.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "utils/utils.h"
 
 /* Handle for our kind of undo operation. */
