@@ -16,13 +16,13 @@
  *     * of the United States of America may require an export license.    * 
  *     *********************************************************************
  *
- * rcsid $Header: /ufs/repository/magic/plot/plotInt.h,v 1.8 2001/08/23 13:48:55 tim Exp $
+ * rcsid $Header: /usr/cvsroot/magic/plot/plotInt.h,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $
  */
 
 #ifndef _PLOTINT_H
 #define _PLOTINT_H
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 
 /* system V machines lack vfont.h, so include the defs below. */
@@ -152,13 +152,12 @@ extern bool PlotGremlinTechLine();
 extern void PlotVersTechInit();
 extern bool PlotVersTechLine();
 
+extern void PlotColorVersTechInit();
+extern bool PlotColorVersTechLine();
+
 extern void PlotPNMTechInit();
 extern bool PlotPNMTechLine();
 extern void PlotPNMTechFinal();
-extern int PlotPNMSetBG();
-
-extern void PlotColorVersTechInit();
-extern bool PlotColorVersTechLine();
 
 extern void PlotPixTechInit();
 extern bool PlotPixTechLine();
@@ -201,6 +200,7 @@ extern int PlotPSHeight;
 extern int PlotPSMargin;
 
 /* for Versatec (plotVers.c): */
+#ifdef VERSATEC
 extern int PlotVersWidth;
 extern int PlotVersDotsPerInch;
 extern int PlotVersSwathHeight;
@@ -211,18 +211,20 @@ extern char *PlotVersIdFont;
 extern char *PlotVersNameFont;
 extern char *PlotVersLabelFont;
 extern bool PlotVersColor;
+#endif
 
 /* for plotPixels.c: */
+#ifdef LLNL
 extern int PlotPixHeight;
 extern int PlotPixWidth;
+#endif
 
 /* for all: */
 extern bool PlotShowCellNames;
 
 /* for plotPnm.c */
 extern int PlotPNMmaxmem;
-extern int PlotPNMBGr;
-extern int PlotPNMBGg;
-extern int PlotPNMBGb;
+extern int PlotPNMdownsample;
+extern int PlotPNMBG;
 
 #endif /* _PLOTINT_H */
