@@ -123,7 +123,7 @@ Font *PlotFontList;		/* Linked list of all fonts that have
 void
 PlotRastInit()
 {
-#ifdef IS_BIG_ENDIAN
+#ifdef WORDS_BIGENDIAN
     int i;
 
     for (i = 0; i < 32; i++)
@@ -132,7 +132,7 @@ PlotRastInit()
 	rightBits[i] = PlotSwapBytes(rightBits[i]);
 	singleBit[i] = PlotSwapBytes(singleBit[i]);
     }
-#endif /* IS_BIG_ENDIAN */
+#endif /* WORDS_BIGENDIAN */
 }
 
 /*
