@@ -18,11 +18,12 @@
  */
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/plow/PlowWidth.c,v 1.3 2001/06/15 15:33:40 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/plow/PlowWidth.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -60,6 +61,7 @@ int plowWidthNumChoices = 0;
  * ----------------------------------------------------------------------------
  */
 
+int
 plowFindWidth(edge, types, bbox, prect)
     Edge *edge;			/* Edge along the LHS of this material */
     TileTypeBitMask types;	/* Types whose width is being computed.  Note
@@ -165,19 +167,20 @@ plowFindWidth(edge, types, bbox, prect)
  * ----------------------------------------------------------------------------
  */
 
+int
 plowInitWidthFunc(tile, wc)
-    register Tile *tile;	/* Tile whose type is not among the types
+    Tile *tile;	/* Tile whose type is not among the types
 				 * passed to plowFindWidth(), whose LHS will
 				 * provide the right-hand boundary.
 				 */
-    register struct wclip *wc;	/* Contains original edge and area to clip */
+    struct wclip *wc;	/* Contains original edge and area to clip */
 {
-    register Edge *edge = wc->wc_edge;
+    Edge *edge = wc->wc_edge;
     int upperBound = LEFT(tile) - edge->e_x;
 
 #ifdef	DEBUGWIDTH
     TxPrintf("Tile type = %s, edgeHeight = %d, upperBound = %d\n",
-	DBTypeLongName(TiGetType(tile)), edge->e_ytop-edge->e_ybot, upperBound);
+	DBTypeLongName(TiGetTypeExact(tile)), edge->e_ytop-edge->e_ybot, upperBound);
 #endif	/* DEBUGWIDTH */
     wc->wc_area.r_ytop = MAX(edge->e_ybot + upperBound, edge->e_ytop);
     wc->wc_area.r_ybot = MIN(edge->e_ytop - upperBound, edge->e_ybot);
@@ -213,17 +216,18 @@ plowInitWidthFunc(tile, wc)
  * ----------------------------------------------------------------------------
  */
 
+int
 plowWidthFunc(tile, wc)
-    register Tile *tile;	/* Tile whose type is not among the types
+    Tile *tile;	/* Tile whose type is not among the types
 				 * passed to plowFindWidth(), which will be
 				 * clipped out of the area wc->wc_area in
 				 * such a way that the original edge will
 				 * remain a part of wc->wc_area.
 				 */
-    register struct wclip *wc;	/* Contains original edge and area to clip */
+    struct wclip *wc;	/* Contains original edge and area to clip */
 {
-    register Edge *edge = wc->wc_edge;
-    register int xw, yw;
+    Edge *edge = wc->wc_edge;
+    int xw, yw;
     int yt, yb;
 
     /*
@@ -315,6 +319,7 @@ clipright:
  * ----------------------------------------------------------------------------
  */
 
+int
 plowFindWidthBack(edge, types, bbox, prect)
     Edge *edge;			/* Edge along the RHS of this material */
     TileTypeBitMask types;	/* Types whose width is being computed.  Note
@@ -417,19 +422,20 @@ plowFindWidthBack(edge, types, bbox, prect)
  * ----------------------------------------------------------------------------
  */
 
+int
 plowInitWidthBackFunc(tile, wc)
-    register Tile *tile;	/* Tile whose type is not among the types
+    Tile *tile;	/* Tile whose type is not among the types
 				 * passed to plowFindWidthBack(), whose RHS will
 				 * provide the left-hand boundary.
 				 */
-    register struct wclip *wc;	/* Contains original edge and area to clip */
+    struct wclip *wc;	/* Contains original edge and area to clip */
 {
-    register Edge *edge = wc->wc_edge;
+    Edge *edge = wc->wc_edge;
     int upperBound = edge->e_x - RIGHT(tile);
 
 #ifdef	DEBUGWIDTH
     TxPrintf("Tile type = %s, edgeHeight = %d, upperBound = %d\n",
-	DBTypeLongName(TiGetType(tile)), edge->e_ytop-edge->e_ybot, upperBound);
+	DBTypeLongName(TiGetTypeExact(tile)), edge->e_ytop-edge->e_ybot, upperBound);
 #endif	/* DEBUGWIDTH */
     wc->wc_area.r_ytop = MAX(edge->e_ybot + upperBound, edge->e_ytop);
     wc->wc_area.r_ybot = MIN(edge->e_ytop - upperBound, edge->e_ybot);
@@ -465,17 +471,18 @@ plowInitWidthBackFunc(tile, wc)
  * ----------------------------------------------------------------------------
  */
 
+int
 plowWidthBackFunc(tile, wc)
-    register Tile *tile;	/* Tile whose type is not among the types
+    Tile *tile;	/* Tile whose type is not among the types
 				 * passed to plowFindWidth(), which will be
 				 * clipped out of the area wc->wc_area in
 				 * such a way that the original edge will
 				 * remain a part of wc->wc_area.
 				 */
-    register struct wclip *wc;	/* Contains original edge and area to clip */
+    struct wclip *wc;	/* Contains original edge and area to clip */
 {
-    register Edge *edge = wc->wc_edge;
-    register int xw, yw;
+    Edge *edge = wc->wc_edge;
+    int xw, yw;
     int yt, yb;
 
     /*
