@@ -18,15 +18,15 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/router/rtrPin.c,v 1.2 2001/01/12 22:13:18 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/router/rtrPin.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "utils/hash.h"
 #include "utils/heap.h"
 #include "debug/debug.h"
@@ -34,15 +34,16 @@ static char rcsid[] = "$Header: /ufs/repository/magic/router/rtrPin.c,v 1.2 2001
 #include "database/database.h"
 #include "gcr/gcr.h"
 #include "windows/windows.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "dbwind/dbwind.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "router/router.h"
 #include "grouter/grouter.h"
 #include "textio/textio.h"
 
 /* Forward declarations */
 bool rtrPinArrayBlock();
+void rtrPinShow(GCRPin *);
 
 
 /*
@@ -391,7 +392,7 @@ rtrPinArrayLink(pins, nPins)
     }
 }
 
-rtrPinShow(pin)
+void rtrPinShow(pin)
     GCRPin *pin;
 {
     char mesg[256];
