@@ -41,7 +41,40 @@ proc magic::resumeall {} {
    }
 }
 
+#--------------------------------------------------------------------------
+# Crash backups.  Create a new crash recovery backup every 10 minutes, or
+# at the interval specified by Opts(backupinterval)
+#--------------------------------------------------------------------------
+
+proc magic::makecrashbackup {} {
+   global Opts
+
+   crash save
+   if {$Opts(backupinterval) > 0} {
+      after $Opts(backupinterval) magic::makecrashbackup
+   }
+}
+
+proc magic::crashbackups {{option start}} {
+   global Opts
+
+   switch -exact $option {
+      start {
+         if {[catch set Opts(backupinterval)]} {
+            set Opts(backupinterval) 600000
+         }
+         after $Opts(backupinterval) magic::makecrashbackup
+      }
+      stop -
+      cancel {
+         after cancel magic::makecrashbackup
+      }
+   }
+}
+
+#--------------------------------------------------------------------------
 # Push and Pop---Treat the edit hierarchy like a stack.
+#--------------------------------------------------------------------------
 
 proc magic::pushstack {{name ""}} {
    global editstack  
@@ -146,6 +179,24 @@ proc magic::peekbox {{type values}} {
    return $b
 }
 
+#---------------------------------------------------------------------
+# Text auto-increment and auto-decrement
+#---------------------------------------------------------------------
+
+proc magic::autoincr {{amount 1}} {
+   set mtext [macro list .]
+   set num [regexp -inline {[+-]*[[:digit:]]+} $mtext]
+   if {$num != ""} {
+      incr num $amount
+      regsub {[+-]*[[:digit:]]+} $mtext $num mtext
+      eval $mtext
+      macro . "$mtext"
+   }
+}
+
+magic::macro XK_plus {magic::autoincr 1}
+magic::macro XK_minus {magic::autoincr -1}
+
 #---------------------------------------------------------------------
 # The following several routines are designed to aid in generating
 # documentation for technology files, or to generate design rule
@@ -365,6 +416,8 @@ proc magic::enable_tools {} {
    set Opts(tool) box
    set Opts(motion) {}
    set Opts(origin) {0 0}
+   set Opts(backupinterval) 60000
+   magic::crashbackups start
 }
 
 #---------------------------------------------------------------------
