@@ -45,15 +45,23 @@ set Glyph(zoom) [image create bitmap \
 # Menu button callback functions
 
 proc magic::promptload {type} {
+   global CAD_ROOT
+
    switch $type {
       cif { set Layoutfilename [ tk_getOpenFile -filetypes \
 		{{CIF {.cif {.cif}}} {"All files" {*}}}]
 	    if {$Layoutfilename != ""} {
 		set cifname [file tail [file root $Layoutfilename]]
-		magic::cellname create $cifname
-		magic::load $cifname
+		magic::cellname create cif_temp
+		magic::load cif_temp
 		magic::cif read [file root $Layoutfilename]
-	    }
+		set childcells [magic::cellname list children cif_temp]
+		magic::load [lindex $childcells 0]
+		magic::cellname delete cif_temp -noprompt
+		if {[llength $childcells] > 1} {
+		   puts stdout "Cells read from GDS file: $childcells"
+		}
+	     }
 	  }
       gds { set Layoutfilename [ tk_getOpenFile -filetypes \
 		{{GDS {.gds .strm .cal {.gds .strm .cal}}} {"All files" {*}}}]
@@ -99,6 +107,8 @@ proc magic::promptload {type} {
 }
 
 proc magic::promptsave {type} {
+   global CAD_ROOT
+
    switch $type {
       cif { set Layoutfilename [ tk_getSaveFile -filetypes \
 		{{CIF {.cif {.cif}}} {"All files" {*}}}]
@@ -419,6 +429,7 @@ proc magic::maketechmanager { mgrpath } {
 
 proc magic::techmanager {{option "update"}} {
    global tcl_precision
+   global CAD_ROOT
 
    if {[catch {wm state .techmgr}]} {
       if {$option == "create"} {
@@ -1129,7 +1140,7 @@ proc magic::openwrapper {{cell ""} {framename ""}} {
    grid ${framename}.titlebar.pos -row 0 -column 5 -sticky news
    grid columnconfigure ${framename}.titlebar 3 -weight 1
 
-   bind $winname <Enter> {focus %W}
+   bind $winname <Enter> "focus %W ; set Opts(focus) $framename"
 
    # Note: Tk binding bypasses the event proc, so it is important to
    # set the current point;  otherwise, the cursor will report the
@@ -1244,10 +1255,15 @@ proc magic::openwrapper {{cell ""} {framename ""}} {
 
    magic::caption ${winname}
 
-   # Remove "open" and "close" macros so they don't generate non-GUI
+   # Change "open" and "close" macros so they don't generate non-GUI
    # windows or (worse) blow away the window inside the GUI frame
-   magic::macro o ""
-   magic::macro O ""
+
+   if {[magic::macro list o] == "openwindow"} {
+      magic::macro o "openwrapper"
+   }
+   if {[magic::macro list O] == "closewindow"} {
+      magic::macro O {closewrapper $Opts(focus)}
+   }
 
    return ${winname}
 }
