@@ -22,13 +22,13 @@
  *
  * Needs to include <stdio.h> and <sys/types.h>
  *
- * rcsid $Header: /ufs/repository/magic/utils/list.h,v 1.2 2001/01/12 22:13:31 jsolomon Exp $
+ * rcsid $Header: /usr/cvsroot/magic/utils/list.h,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $
  */
 
 #ifndef	_LIST_H
 #define	_LIST_H
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 
 /* --------------------- Lists (Lisp like) ---------------------------- */
 
