@@ -24,16 +24,13 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/util
 
 #include <stdio.h>
 #include <stdlib.h>
-#ifndef SYSV
-#include <strings.h>
-#else
 #include <string.h>
-#endif
 
 #include <sys/types.h>
 #include <sys/times.h>
 #include <sys/time.h>
 
+#include "utils/main.h"
 #include "utils/magic.h"
 #include "utils/malloc.h"
 #include "utils/magsgtty.h"
@@ -91,10 +88,15 @@ global char	*SysLibPath = NULL;	/* Used to find color maps, styles, */
 					/* technologies, etc. */
 
 /*
- * Flag that tells if the '-D' (debugging) option is set.
+ * Flag that tells if various options have been set on the command line
+ * (see utils.h for explanation of individual flags).
  */
 
-global bool mainDebug = FALSE;
+#ifdef MAGIC_WRAPPER
+global short RuntimeFlags = MAIN_MAKE_WINDOW | MAIN_TK_CONSOLE;
+#else
+global short RuntimeFlags = MAIN_MAKE_WINDOW;
+#endif
 
 /*
  * See the file main.h for a description of the information kept
@@ -126,14 +128,6 @@ FileName *CurrentName;
 global char *MainGraphicsFile = NULL;
 global char *MainMouseFile = NULL;
 
-#ifdef MAGIC_WRAPPER
-/* the name of the first window, if it is not to be a top-level window */
-global bool MakeMainWindow = TRUE;
-global bool TxTkConsole = TRUE;
-#else
-#define MakeMainWindow TRUE
-#endif
-
 /* information about the color display. */
 global char *MainDisplayType = NULL;
 global char *MainMonType = NULL;
@@ -143,12 +137,6 @@ global char *MainMonType = NULL;
 global char *MainCopyright = "\n--- MAGIC: Copyright (C) 1985, 1990 "
 		"Regents of the University of California.  ---\n";
 
-
-/* If TRUE, then Magic is as silent as possible.  This is only set to
- * TRUE by batch programs such as Mpack and Mocha Chip.
- */
-global bool MainSilent = FALSE;
-
 /* Forward declarations */
 char *mainArg();
 
@@ -179,9 +167,7 @@ MainExit(errNum)
 			     */
 	GrClose();
 
-#ifdef FILE_LOCKS
-    flock_exit();
-#endif
+    DBRemoveBackup();
 
     TxFlush();
     TxResetTerminal();
@@ -263,11 +249,18 @@ mainDoArgs(argc, argv)
 		    TechOverridesDefault = TRUE;
 		    break;
 
+		/*
+		 * Recover a crash file.
+		 */
+		case 'r':
+		    RuntimeFlags |= MAIN_RECOVER;
+		    break;
+
 		/* 
 		 * We are being debugged.
 		 */
 		case 'D':
-		    mainDebug = TRUE;
+		    RuntimeFlags |= MAIN_DEBUG;
 		    break;
 
 #ifdef MAGIC_WRAPPER
@@ -275,7 +268,7 @@ mainDoArgs(argc, argv)
 		 * "-w" for wrapper * implies -nowindow (no initial window)
 		 */
 		case 'w':
-		    MakeMainWindow = FALSE;
+		    RuntimeFlags &= ~MAIN_MAKE_WINDOW;
 		    break;
 		/*
 		 * No initial window / no console options.
@@ -288,9 +281,9 @@ mainDoArgs(argc, argv)
 			return 1;
 		    }
 		    else if (argv[0][3] == 'c')
-			TxTkConsole = FALSE;
+			RuntimeFlags &= ~MAIN_TK_CONSOLE;
 		    else if (argv[0][3] == 'w')
-			MakeMainWindow = FALSE;
+			RuntimeFlags &= ~MAIN_MAKE_WINDOW;
 		    break;
 #endif
 		default:
@@ -467,10 +460,6 @@ mainInitAfterArgs()
     SectionID sec_drc, sec_extract, sec_wiring, sec_router;
     SectionID sec_plow, sec_plot, sec_mzrouter;
 
-#ifdef FILE_LOCKS
-    flock_init();
-#endif
-
     /* If no technology has been specified yet, try to read one from
      * the initial cell, or else assign a default.
      */
@@ -783,11 +772,23 @@ mainInitFinal()
 	(void) fclose(f);
     }
 
+    /*
+     * Recover crash files from the temp directory if we have specified
+     * the -r option on the command line (non-tcl version.  Tcl version
+     * uses the command-line command crashrecover.
+     */
+
+    if (mainRecover && MakeMainWindow)
+    {
+	DBFileRecovery();
+    }
+
     /*
      * Bring in a new cell or cells to start up if one was given
      * on the command line
      */
-    if (MainFileName && MakeMainWindow)
+
+    else if (MainFileName && MakeMainWindow)
     {
 	FileName *temporary;
 
