@@ -82,7 +82,6 @@ windBorderCmd(w, cmd)
     bool value;
     static char *onoff[] = {"on", "off", 0};
     static bool truth[] = {TRUE, FALSE};
-    extern int windDefaultFlags;
 
     if (cmd->tx_argc > 2) goto usage;
     else if (cmd->tx_argc == 1)
@@ -93,7 +92,7 @@ windBorderCmd(w, cmd)
 	    goto usage;
 	}
 
-	value = (w->w_flags & WIND_BORDER) ? TRUE : FALSE;
+	value = (w->w_flags & WIND_BORDER) ? 0 : 1;
 
 #ifdef MAGIC_WRAPPER
 	Tcl_SetResult(magicinterp, onoff[value], TCL_STATIC);
@@ -109,11 +108,11 @@ windBorderCmd(w, cmd)
 
     if (truth[place])
     {
-        windDefaultFlags |= WIND_BORDER;
+        WindDefaultFlags |= WIND_BORDER;
 	TxPrintf("New windows will have a border.\n");
     }
     else {
-        windDefaultFlags &= ~WIND_BORDER;
+        WindDefaultFlags &= ~WIND_BORDER;
 	TxPrintf("New windows will not have a border.\n");
     }
     return;
@@ -152,7 +151,6 @@ windCaptionCmd(w, cmd)
     Rect ts;
     static char *onoff[] = {"on", "off", 0};
     static bool truth[] = {TRUE, FALSE};
-    extern int windDefaultFlags;
 
     if (cmd->tx_argc > 2) goto usage;
     else if (cmd->tx_argc == 1)
@@ -177,11 +175,11 @@ windCaptionCmd(w, cmd)
 
     if (truth[place])
     {
-        windDefaultFlags |= WIND_CAPTION;
+        WindDefaultFlags |= WIND_CAPTION;
 	TxPrintf("New windows will have a title caption.\n");
     }
     else {
-        windDefaultFlags &= ~WIND_CAPTION;
+        WindDefaultFlags &= ~WIND_CAPTION;
 	TxPrintf("New windows will not have a title caption.\n");
     }
     return;
@@ -346,9 +344,6 @@ windCloseCmd(w, cmd)
 	TxError("Unable to close that window\n");
 	return;
     }
-#ifdef FILE_LOCKS
-    flock_close_wlist(w);
-#endif
 }
 
 #ifdef MAGIC_WRAPPER
@@ -598,13 +593,6 @@ windFilesCmd(w, cmd)
     struct stat buf;
     int unopen, open;
 
-#ifdef FILE_LOCKS
-    if (cmd->tx_argc > 1)
-    {
-	flock_print();
-	return;
-    }
-#endif
     open = unopen = 0;
     for (fd = 0; fd < NUM_FD; fd++) {
 	if (fstat(fd, &buf) != 0) {
@@ -917,6 +905,7 @@ windDoMacro(w, cmd, interactive)
     char ch;
     int ct, argstart;
     bool any, iReturn;
+    bool do_list = FALSE;
     macrodef *cMacro;
     HashTable *clienttable;
     HashEntry *h;
@@ -958,6 +947,15 @@ windDoMacro(w, cmd, interactive)
 	    argstart = 2;
     }
 
+    if (cmd->tx_argc > argstart)
+    {
+	if (!strcmp(cmd->tx_argv[argstart], "list"))
+	{
+	    do_list = TRUE;
+	    argstart++;
+	}
+    }
+
     if (cmd->tx_argc == argstart)
     {
 	h = HashLookOnly(&MacroClients, wc);
@@ -984,21 +982,29 @@ windDoMacro(w, cmd, interactive)
 	    cp = cMacro->macrotext;
 	    cn = MacroName((int)h->h_key.h_ptr);
 
-	    if (cMacro->interactive)
+	    if (do_list)
 	    {
-		TxPrintf("Interactive macro '%s' contains \"%s\"\n",
-			     cn, cp);
+#ifdef MAGIC_WRAPPER
+		Tcl_AppendElement(magicinterp, cp);
+#else
+		TxPrintf("%s\n", cp);
+#endif
 	    }
 	    else
 	    {
-		TxPrintf("Macro '%s' contains \"%s\"\n",
+	        if (cMacro->interactive)
+		    TxPrintf("Interactive macro '%s' contains \"%s\"\n",
 			     cn, cp);
+		else
+		    TxPrintf("Macro '%s' contains \"%s\"\n", cn, cp);
 	    }
 	    freeMagic(cn);
 	    any = TRUE;
 	}
 	if (!any)
-	    TxPrintf("No macros are defined for this client.\n");
+	{
+	    if (!do_list) TxPrintf("No macros are defined for this client.\n");
+	}
 	return;
     }
     else if (cmd->tx_argc == (argstart + 1))
@@ -1015,15 +1021,26 @@ windDoMacro(w, cmd, interactive)
 	if (cp != NULL)
 	{
 	    cn = MacroName(ct);
-	    if (iReturn)
+	    if (do_list)
 	    {
-		TxPrintf("Interactive macro '%s' contains \"%s\"\n",
-			 cn, cp);
+#ifdef MAGIC_WRAPPER
+		Tcl_SetResult(magicinterp, cp, TCL_VOLATILE);
+#else
+		TxPrintf("%s\n", cp);
+#endif
 	    }
 	    else
 	    {
-		TxPrintf("Macro '%s' contains \"%s\"\n",
-			 cn, cp);
+		if (iReturn)
+		{
+		    TxPrintf("Interactive macro '%s' contains \"%s\"\n",
+			 	cn, cp);
+		}
+		else
+		{
+		    TxPrintf("Macro '%s' contains \"%s\"\n",
+				cn, cp);
+		}
 	    }
 	    freeMagic(cp);
 	    freeMagic(cn);
