@@ -452,7 +452,6 @@ usage:
     return;
 }
 
-#ifdef MAGIC_WRAPPER
 /*
  * ----------------------------------------------------------------------------
  *  windNamesCmd --
@@ -479,7 +478,7 @@ windNamesCmd(w, cmd)
     TxCommand *cmd;
 {
     bool doforall = FALSE;
-    WindClient wc = NULL;
+    WindClient wc = (WindClient)NULL;
     MagWindow *sw;
 
     if (cmd->tx_argc > 2)
@@ -513,19 +512,57 @@ windNamesCmd(w, cmd)
 	    doforall = TRUE;
     }
 
+#ifdef MAGIC_WRAPPER
     if (doforall == TRUE)
     {
+	Tcl_Obj *tlist;
+
+	tlist = Tcl_NewListObj(0, NULL);
 	for (sw = windTopWindow; sw != NULL; sw = sw->w_nextWindow)
 	    if ((wc == NULL) || (sw->w_client == wc))
-		Tcl_AppendElement(magicinterp, (*GrWindowNamePtr)(sw));
+	    {
+		if (GrWindowNamePtr)
+		    Tcl_ListObjAppendElement(magicinterp, tlist,
+				Tcl_NewStringObj((*GrWindowNamePtr)(sw), -1));
+		else
+		    Tcl_ListObjAppendElement(magicinterp, tlist,
+				Tcl_NewIntObj(sw->w_wid));
+	    }
+	Tcl_SetObjResult(magicinterp, tlist);
     }
     else
     {
 	if (GrWindowNamePtr)
 	    Tcl_SetResult(magicinterp, (*GrWindowNamePtr)(w), NULL);
+	else
+	    Tcl_SetObjResult(magicinterp, Tcl_NewIntObj(w->w_wid));
     }
+#else
+    if (doforall == TRUE)
+    {
+	if (GrWindowNamePtr)
+	    TxPrintf("Window ID	Window Name\n");
+	else
+	    TxPrintf("Window ID\n");
+	for (sw = windTopWindow; sw != NULL; sw = sw->w_nextWindow)
+	    if ((wc == (WindClient)NULL) || (sw->w_client == wc))
+	    {
+		if (GrWindowNamePtr)
+		    TxPrintf("%d    	%s\n", sw->w_wid, (*GrWindowNamePtr)(sw));
+		else
+		    TxPrintf("%d\n", sw->w_wid);
+	    }
+    }
+    else
+    {
+	if (GrWindowNamePtr)
+	    TxPrintf("Window ID = %d, Name = %s\n", w->w_wid,
+			(*GrWindowNamePtr)(w));
+	else
+	    TxPrintf("Window ID = %d\n", w->w_wid);
+    }
+#endif /* !MAGIC_WRAPPER */
 }
-#endif
 
 
 /*
@@ -908,7 +945,6 @@ windScrollBarsCmd(w, cmd)
     int place;
     static char *onoff[] = {"on", "off", 0};
     static bool truth[] = {TRUE, FALSE};
-    extern int windDefaultFlags;
 
     if (cmd->tx_argc != 2) goto usage;
 
@@ -917,12 +953,12 @@ windScrollBarsCmd(w, cmd)
 
     if (truth[place])
     {
-	windDefaultFlags |= WIND_SCROLLBARS;
+	WindDefaultFlags |= WIND_SCROLLBARS;
 	TxPrintf("New windows will have scroll bars.\n");
     }
     else
     {
-	windDefaultFlags &= ~WIND_SCROLLBARS;
+	WindDefaultFlags &= ~WIND_SCROLLBARS;
 	TxPrintf("New windows will not have scroll bars.\n");
     }
     return;
